* fdr adjustment within survey round *

eststo clear
clear

cap program drop FDR_LATE
program define FDR_LATE // Use to adjust P-value in LATE analysis

quietly {

    tempfile full 
    sa `full'
    
    clear 
    
    svmat $group
    keep *4
    rename *4 A4
    drop if A4 ==.
    gen float pval = A4
    
    
* Collect the total number of p-values tested
quietly sum pval
local totalpvals = r(N)

* Sort the p-values in ascending order and generate a variable that codes each p-value's rank
quietly gen int original_sorting_order = _n
quietly sort pval
quietly gen int rank = _n if pval~=.

* Set the initial counter to 1
local qval = 1

* Generate the variable that will contain the BKY (2006) sharpened q-values
gen bky06_qval = 1 if pval~=.

* Set up a loop that begins by checking which hypotheses are rejected at q = 1.000, then checks which hypotheses are rejected at q = 0.999, then checks which hypotheses are rejected at q = 0.998, etc.  The loop ends by checking which hypotheses are rejected at q = 0.001.
while `qval' > 0 {
    * First Stage
    * Generate the adjusted first stage q level we are testing: q' = q/1+q
    local qval_adj = `qval'/(1+`qval')
    * Generate value q'*r/M
    gen fdr_temp1 = `qval_adj'*rank/`totalpvals'
    * Generate binary variable checking condition p(r) <= q'*r/M
    gen reject_temp1 = (fdr_temp1>=pval) if pval~=.
    * Generate variable containing p-value ranks for all p-values that meet above condition
    gen reject_rank1 = reject_temp1*rank
    * Record the rank of the largest p-value that meets above condition
    egen total_rejected1 = max(reject_rank1)

    * Second Stage
    * Generate the second stage q level that accounts for hypotheses rejected in first stage: q_2st = q'*(M/m0)
    local qval_2st = `qval_adj'*(`totalpvals'/(`totalpvals'-total_rejected1[1]))
    * Generate value q_2st*r/M
    gen fdr_temp2 = `qval_2st'*rank/`totalpvals'
    * Generate binary variable checking condition p(r) <= q_2st*r/M
    gen reject_temp2 = (fdr_temp2>=pval) if pval~=.
    * Generate variable containing p-value ranks for all p-values that meet above condition
    gen reject_rank2 = reject_temp2*rank
    * Record the rank of the largest p-value that meets above condition
    egen total_rejected2 = max(reject_rank2)

    * A p-value has been rejected at level q if its rank is less than or equal to the rank of the max p-value that meets the above condition
    replace bky06_qval = `qval' if rank <= total_rejected2 & rank~=.
    * Reduce q by 0.001 and repeat loop
    drop fdr_temp* reject_temp* reject_rank* total_rejected*
    local qval = `qval' - .001
}

quietly sort original_sorting_order
mkmat bky06_qval, matrix(Qval)
}

display "Code has completed."
display "Benjamini Krieger Yekutieli (2006) sharpened q-vals are in variable 'bky06_qval'"
mat list Qval
display    "Sorting order is the same as the original vector of p-values"
use "`full'", clear
end


use "$panel/ready.dta"

local ffx strat_pmt strat_vill_size roundcohort
local subffx strat_pmt strat_vill_size
local controls i.surveyed_twice

gen tmpvar = proxycon_mt
replace tmpvar = proxycon_mt_compare if svyround == 2 | svyround == 4
label variable tmpvar "\makecell{Food \\ consumption}"

local primary_panel fcs tmpvar
local mentalhealth_panel stair_satis_today mentalhealth vperception socialcohesion

capture rename saved_binary_ saved_binary

local finance_panel loans_twelve_mo loans_amt saved_binary saved_total remittance_amt risk_sharing

capture rename trans_fam trans_rec

local remittances_panel trans_rec remittance_amt trans_fam_send remittance_sent_amt risk_sharing

local bus_panel nbusiness bus_asset_value bus_profit

local wage_panel non_agri_emp_binary non_agri_wages

local agri_panel hasplots30 crop_seed30 agri_wages livestock_tlu
// local agri_panel livestock_tlu agri_emp_binary 
// tlu index livestock count TLU livestock_tlu

forval i = 1/4 {
    mat def pvalue_index_`i' = J(6, 4, .)
    local counter_index 1
    foreach depvar in fcs tmpvar cantril {
        {
        reghdfe `depvar' i.treatment `controls' if svyround == `i', absorb(`ffx') vce(cluster vid)
        eststo `depvar'_`i'
        mat def pvalue_index_`i'[`counter_index', 4] = r(table)["pvalue", "1.treatment"]
        local ++counter_index
        mat def pvalue_index_`i'[`counter_index', 4] = r(table)["pvalue", "2.treatment"]
        local ++counter_index
    
        test 1.treatment = 2.treatment
        estadd scalar equals = r(p)
        estadd local ffx = "Yes"
        estadd scalar ar2 = e(r2_a)
    
        forval k = 0/2 {
            sum `depvar' if treatment == `k' & e(sample) == 1
            estadd scalar mean_`k' = r(mean)
            }
            }
            }
            }

di `counter_index'
mat list pvalue_index_1
mat list pvalue_index_2
mat list pvalue_index_3
mat list pvalue_index_4

forval i = 1/4 {
global group "pvalue_index_`i'" // define global which accepts the matrix of pvalues
FDR_LATE // apply false discovery rate adjustment
mat Q`i' = (Qval)'
}

local topnames 1.treatment 2.treatment 1.treatment 2.treatment 1.treatment 2.treatment

forval i = 1/4 {
mat colnames Q`i' = `topnames'    
}

* collect values for first outcome for each round

forval i = 1/4 {
di as error "`i'"
local j = 1
local k = `j' + 1

matrix qval = Q`i'[1, `j'..`k']
mat rownames qval = y1
mat list qval
estadd matrix qval: fcs_`i'

}

* collect values for second outcome for each round

forval i = 1/4 {
local j = 3
local k = `j' + 1

matrix qval = Q`i'[1, `j'..`k']
mat rownames qval = y1
mat list qval
estadd matrix qval: tmpvar_`i'

}

* collect values for third outcome for each round

forval i = 1/4 {
local j = 5
local k = `j' + 1

matrix qval = Q`i'[1, `j'..`k']
mat rownames qval = y1
mat list qval
estadd matrix qval: cantril_`i'

}

reghdfe fcs i.treatment##i.svyround `controls' if svyround < 3, absorb(`subffx') vce(cluster vid)
eststo nested_fcs

test (1.treatment = 1.treatment + 2.svyround + 1.treatment#2.svyround)
estadd scalar fpval1 = r(p)

test (2.treatment = 2.treatment + 2.svyround + 2.treatment#2.svyround)
estadd scalar fpval2 = r(p)
/*
esttab nested_fcs ///
using "$csae/nested-fcs.tex", ///
keep(1.treatment 2.treatment ///
2.svyround ///
1.treatment#2.svyround ///
2.treatment#2.svyround ///
) ///
cells( ///
"b(pattern() fmt(%12.2f) star pvalue(p))" ///
"se(pattern() fmt(%12.2f) par)" ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
mtitle("FCS") ///
nonumbers ///
collabels(none) ///
stats(fpval1 fpval2 N, labels() fmt(2 2 0)) ///
booktab ///
replace
*/
test 1.treatment + (1.treatment + 1.treatment#2.svyround) = 0
estadd scalar int1 = r(p)
scalar int1 = r(p)

test 2.treatment + (2.treatment + 2.treatment#2.svyround) = 0
estadd scalar int2 = r(p)
scalar int2 = r(p)

matrix b = (int1, int2)
mat colnames b = 1.treatment 2.treatment
ereturn post b
eststo fcs_int

quietly reghdfe tmpvar i.treatment##i.svyround `controls' if svyround < 3, absorb(`subffx') vce(cluster vid)
eststo nested_tmpvar

test (1.treatment = 1.treatment + 2.svyround + 1.treatment#2.svyround)
estadd scalar fpval1 = r(p)

test (2.treatment = 2.treatment + 2.svyround + 2.treatment#2.svyround)
estadd scalar fpval2 = r(p)
/*
esttab nested_tmpvar ///
using "$csae/nested-tmpvar.tex", ///
keep(1.treatment 2.treatment ///
2.svyround ///
1.treatment#2.svyround ///
2.treatment#2.svyround ///
) ///
cells( ///
"b(pattern() fmt(%12.2f) star pvalue(p))" ///
"se(pattern() fmt(%12.2f) par)" ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
mtitle("Food consumption") ///
nonumbers ///
collabels(none) ///
stats(fpval1 fpval2 N, labels() fmt(2 2 0)) ///
booktab ///
replace
*/
test 1.treatment + (1.treatment + 1.treatment#2.svyround) = 0
estadd scalar int1 = r(p)
scalar int1 = r(p)

test 2.treatment + (2.treatment + 2.treatment#2.svyround) = 0
estadd scalar int2 = r(p)
scalar int2 = r(p)

matrix b = (int1, int2)
mat colnames b = 1.treatment 2.treatment
ereturn post b
eststo tmpvar_int

quietly reghdfe cantril i.treatment##i.svyround `controls' if svyround < 3, absorb(`subffx') vce(cluster vid)
eststo nested_cantril

test (1.treatment = 1.treatment + 2.svyround + 1.treatment#2.svyround)
estadd scalar fpval1 = r(p)

test (2.treatment = 2.treatment + 2.svyround + 2.treatment#2.svyround)
estadd scalar fpval2 = r(p)

test 1.treatment + (1.treatment + 1.treatment#2.svyround) = 0
estadd scalar int1 = r(p)
scalar int1 = r(p)

test 2.treatment + (2.treatment + 2.treatment#2.svyround) = 0
estadd scalar int2 = r(p)
scalar int2 = r(p)

matrix b = (int1, int2)
mat colnames b = 1.treatment 2.treatment
ereturn post b
eststo cantril_int
/*
* run regressions by treatment arm

foreach depvar in fcs tmpvar cantril {
forval i = 0/2 {
    reghdfe `depvar' i.svyround `controls' if treatment == `i' & svyround < 3, absorb(`subffx') vce(cluster vid)
    eststo arm_`depvar'_`i'
    
    test 2.svyround = 0 = 1.svyround
    estadd scalar veq = r(p)
    scalar sv_`depvar'_`i' = r(p)
    
//     test 1.svyround + 2.svyround = 0
//     estadd scalar ieq = r(p)
//     test 1.svyround = 2.svyround
//     estadd scalar seq = r(p)
//     test 1.svyround = 2.svyround = 0
//     estadd scalar deq = r(p)
}
}

foreach depvar in fcs tmpvar cantril {
    regress hhid
    eststo `depvar'_empty
    estadd local N = "", replace
    estadd scalar mean_0 = sv_`depvar'_0
    estadd scalar mean_1 = sv_`depvar'_1
    estadd scalar mean_2 = sv_`depvar'_2
}
*/
/*
esttab arm_fcs_* ///
using "$csae/fcs-by-arm.tex", ///
cells( ///
"b(pattern() fmt(%12.2f) star pvalue(p))" ///
"se(pattern() fmt(%12.2f) par)" ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
mtitle("Trad. response" "Early short" "Early long") ///
nonumbers ///
collabels(none) ///
keep(2.svyround) ///
booktabs ///
stats(veq N, ///
labels("Lean = 0" "Observations") fmt(2 0)) ///
replace

esttab arm_tmpvar_* ///
using "$csae/fcons-by-arm.tex", ///
cells( ///
"b(pattern() fmt(%12.2f) star pvalue(p))" ///
"se(pattern() fmt(%12.2f) par)" ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
mtitle("Trad. response" "Early short" "Early long") ///
nonumbers ///
collabels(none) ///
keep(2.svyround) ///
booktabs ///
stats(veq N, ///
labels("Lean = 0" "Observations") fmt(2 0)) ///
replace

esttab arm_cantril_* ///
using "$csae/cantril-by-arm.tex", ///
cells( ///
"b(pattern() fmt(%12.2f) star pvalue(p))" ///
"se(pattern() fmt(%12.2f) par)" ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
mtitle("Trad. response" "Early short" "Early long") ///
nonumbers ///
collabels(none) ///
keep(2.svyround) ///
booktabs ///
stats(veq N, ///
labels("Lean = 0" "Observations") fmt(2 0)) ///
replace
*/
esttab fcs_* ///
    using "$csae/primary-panel.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    "qval(pattern() fmt(%12.2f) par([ ]))" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Pre-lean" "Lean" "Post-lean" "Endline" "\shortstack{Pre-lean + Lean \\ = 0}") ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 mean_1 mean_2 N, ///
    labels("Early short = Early long" "Trad. response mean" "Early short mean" "Early long mean" "Observations") fmt(2 2 2 2 0)) ///
    posthead( ///
    \midrule ///
    \it{Food Security} \\ ///
    \midrule ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    replace
    
esttab tmpvar_* ///
    using "$csae/primary-panel.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    "qval(pattern() fmt(%12.2f) par([ ]))" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 mean_1 mean_2 N, ///
    labels("Early short = Early long" "Trad. response mean" "Early short mean" "Early long mean" "Observations") fmt(2 2 2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Food Consumption} \\ ///
    ) ///
    append
    
    
forval i = 1/4 {
foreach depvar in mentalhealth {
    {
    reghdfe `depvar' i.treatment `controls' if svyround == `i', absorb(`ffx') vce(cluster vid)
    eststo `depvar'_`i'
    test 1.treatment == 2.treatment
    estadd scalar equals = r(p)
    estadd local ffx = "Yes"
    estadd scalar ar2 = e(r2_a)
    forval k = 0/2 {
        sum `depvar' if treatment == `k' & e(sample) == 1
        estadd scalar mean_`k' = r(mean)
    }
    }
}
}

foreach depvar in mentalhealth {
reghdfe `depvar' i.treatment##i.svyround `controls' if svyround < 3, absorb(strat_pmt strat_vill_size) vce(cluster vid)
eststo nested_`depvar'

test (2.svyround = 0)
estadd scalar fpval0 = r(p)

test (1.treatment = 1.treatment + 2.svyround + 1.treatment#2.svyround)
estadd scalar fpval1 = r(p)

test (2.treatment = 2.treatment + 2.svyround + 2.treatment#2.svyround)
estadd scalar fpval2 = r(p)

test 1.treatment + (1.treatment + 1.treatment#2.svyround) = 0
estadd scalar int1 = r(p)
scalar int1 = r(p)

test 2.treatment + (2.treatment + 2.treatment#2.svyround) = 0
estadd scalar int2 = r(p)
scalar int2 = r(p)

matrix b = (int1, int2)
mat colnames b = 1.treatment 2.treatment
ereturn post b
eststo `depvar'_int
}

/*
* run regressions by treatment arm

foreach depvar in mentalhealth {
forval i = 0/2 {
    reghdfe `depvar' i.svyround `controls' if treatment == `i' & svyround < 3, absorb(`subffx') vce(cluster vid)
    eststo arm_`depvar'_`i'
    
    test 2.svyround = 0 = 1.svyround
    estadd scalar veq = r(p)
    scalar sv_`depvar'_`i' = r(p)
    
//     test 1.svyround + 2.svyround = 0
//     estadd scalar ieq = r(p)
//     test 1.svyround = 2.svyround
//     estadd scalar seq = r(p)
//     test 1.svyround = 2.svyround = 0
//     estadd scalar deq = r(p)
}
}

foreach depvar in mentalhealth {
    regress hhid
    eststo `depvar'_empty
    estadd local N = "", replace
    estadd scalar mean_0 = sv_`depvar'_0
    estadd scalar mean_1 = sv_`depvar'_1
    estadd scalar mean_2 = sv_`depvar'_2
}
*/
esttab cantril_* ///
    using "$csae/mhealth-panel.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    "qval(pattern() fmt(%12.2f) par([ ]))" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Pre-lean" "Lean" "Post-lean" "Endline" "\shortstack{Pre-lean + Lean \\ = 0}") ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 mean_1 mean_2 N, ///
    labels("Early short = Early long" "Trad. response mean" "Early short mean" "Early long mean" "Observations") fmt(2 2 2 2 0)) ///
    posthead( ///
    \midrule ///
    \it{Life Satisfaction} \\ ///
    \midrule ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    replace
  
esttab mentalhealth_* ///
    using "$csae/mhealth-panel.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 mean_1 mean_2 N, ///
    labels("Early short = Early long" "Trad. response mean" "Early short mean" "Early long mean" "Observations") fmt(2 2 2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Mental health index} \\ ///
    ) ///
    append
/*
esttab nested_cantril ///
using "$csae/nested-cantril.tex", ///
keep(1.treatment 2.treatment ///
2.svyround ///
1.treatment#2.svyround ///
2.treatment#2.svyround ///
) ///
cells( ///
"b(pattern() fmt(%12.2f) star pvalue(p))" ///
"se(pattern() fmt(%12.2f) par)" ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
mtitle("Life satisfaction") ///
nonumbers ///
collabels(none) ///
stats(fpval0 fpval1 fpval2 N, labels() fmt(2 2 2 0)) ///
booktab ///
replace

esttab nested_mentalhealth ///
using "$csae/nested-mentalhealth.tex", ///
keep(1.treatment 2.treatment ///
2.svyround ///
1.treatment#2.svyround ///
2.treatment#2.svyround ///
) ///
cells( ///
"b(pattern() fmt(%12.2f) star pvalue(p))" ///
"se(pattern() fmt(%12.2f) par)" ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
mtitle("Mental health index") ///
nonumbers ///
collabels(none) ///
stats(fpval0 fpval1 fpval2 N, labels() fmt(2 2 2 0)) ///
booktab ///
replace
*/

* with baseline controls selected using lasso *
    
eststo clear

merge m:1 hhid using "$baseline_final/dslasso-selected-vars.dta"
drop _merge
ds bl_*
local baseline_controls `r(varlist)'
// local baseline_controls i.surveyed_twice mem_n hhh_fem poly hhh_age hhh_edu hhh_prim hhh_noeduc hhh_lit depend child_school

forval i = 1/4 {
    mat def pvalue_index_`i' = J(6, 4, .)
    local counter_index 1
    foreach depvar in fcs tmpvar cantril {
        {
        reghdfe `depvar' i.treatment `baseline_controls' if svyround == `i', absorb(`ffx') vce(cluster vid)
        eststo `depvar'_`i'
        mat def pvalue_index_`i'[`counter_index', 4] = r(table)["pvalue", "1.treatment"]
        local ++counter_index
        mat def pvalue_index_`i'[`counter_index', 4] = r(table)["pvalue", "2.treatment"]
        local ++counter_index
    
        test 1.treatment = 2.treatment
        estadd scalar equals = r(p)
        estadd local ffx = "Yes"
        estadd scalar ar2 = e(r2_a)
    
        forval k = 0/2 {
            sum `depvar' if treatment == `k' & e(sample) == 1
            estadd scalar mean_`k' = r(mean)
            }
            }
            }
            }

di `counter_index'
mat list pvalue_index_1
mat list pvalue_index_2
mat list pvalue_index_3
mat list pvalue_index_4

forval i = 1/4 {
global group "pvalue_index_`i'" // define global which accepts the matrix of pvalues
FDR_LATE // apply false discovery rate adjustment
mat Q`i' = (Qval)'
}

local topnames 1.treatment 2.treatment 1.treatment 2.treatment 1.treatment 2.treatment

forval i = 1/4 {
mat colnames Q`i' = `topnames'    
}

* collect values for first outcome for each round

forval i = 1/4 {
di as error "`i'"
local j = 1
local k = `j' + 1

matrix qval = Q`i'[1, `j'..`k']
mat rownames qval = y1
mat list qval
estadd matrix qval: fcs_`i'

}

* collect values for second outcome for each round

forval i = 1/4 {
local j = 3
local k = `j' + 1

matrix qval = Q`i'[1, `j'..`k']
mat rownames qval = y1
mat list qval
estadd matrix qval: tmpvar_`i'

}

* collect values for third outcome for each round

forval i = 1/4 {
local j = 5
local k = `j' + 1

matrix qval = Q`i'[1, `j'..`k']
mat rownames qval = y1
mat list qval
estadd matrix qval: cantril_`i'

}

reghdfe fcs i.treatment##i.svyround `controls' if svyround < 3, absorb(`subffx') vce(cluster vid)

test 1.treatment + (1.treatment + 1.treatment#2.svyround) = 0
estadd scalar int1 = r(p)
scalar int1 = r(p)

test 2.treatment + (2.treatment + 2.treatment#2.svyround) = 0
estadd scalar int2 = r(p)
scalar int2 = r(p)

matrix b = (int1, int2)
mat colnames b = 1.treatment 2.treatment
ereturn post b
eststo fcs_int

quietly reghdfe tmpvar i.treatment##i.svyround `controls' if svyround < 3, absorb(`subffx') vce(cluster vid)

test 1.treatment + (1.treatment + 1.treatment#2.svyround) = 0
estadd scalar int1 = r(p)
scalar int1 = r(p)

test 2.treatment + (2.treatment + 2.treatment#2.svyround) = 0
estadd scalar int2 = r(p)
scalar int2 = r(p)

matrix b = (int1, int2)
mat colnames b = 1.treatment 2.treatment
ereturn post b
eststo tmpvar_int


quietly reghdfe cantril i.treatment##i.svyround `controls' if svyround < 3, absorb(`subffx') vce(cluster vid)

test 1.treatment + (1.treatment + 1.treatment#2.svyround) = 0
estadd scalar int1 = r(p)
scalar int1 = r(p)

test 2.treatment + (2.treatment + 2.treatment#2.svyround) = 0
estadd scalar int2 = r(p)
scalar int2 = r(p)

matrix b = (int1, int2)
mat colnames b = 1.treatment 2.treatment
ereturn post b
eststo cantril_int

esttab fcs_* ///
    using "$csae/primary-outcomes-controls.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    "qval(pattern() fmt(%12.2f) par([ ]))" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Pre-lean" "Lean" "Post-lean" "Endline" "\shortstack{Pre-lean + Lean \\ = 0}") ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 mean_1 mean_2 N, ///
    labels("Early short = Early long" "Trad. response mean" "Early short mean" "Early long mean" "Observations") fmt(2 2 2 2 0)) ///
    posthead( ///
    \midrule ///
    \it{Food Security} \\ ///
    \midrule ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    replace
    
esttab tmpvar_* ///
    using "$csae/primary-outcomes-controls.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    "qval(pattern() fmt(%12.2f) par([ ]))" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 mean_1 mean_2 N, ///
    labels("Early short = Early long" "Trad. response mean" "Early short mean" "Early long mean" "Observations") fmt(2 2 2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Food Consumption} \\ ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    append    
    
    
esttab cantril_* ///
    using "$csae/primary-outcomes-controls.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    "qval(pattern() fmt(%12.2f) par([ ]))" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 mean_1 mean_2 N, ///
    labels("Early short = Early long" "Trad. response mean" "Early short mean" "Early long mean" "Observations") fmt(2 2 2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Life Satisfaction} \\ ///
    ) ///
    append

* estimate food consumption for extended list, lean and endline

eststo clear

rename proxycon_mt foodext

forval i = 2(2)4 {
    mat def pvalue_index_`i' = J(6, 4, .)
    local counter_index 1
    foreach depvar in foodext {
        {
        reghdfe `depvar' i.treatment i.surveyed_twice if svyround == `i', absorb(`ffx') vce(cluster vid)
        eststo `depvar'_`i'
        mat def pvalue_index_`i'[`counter_index', 4] = r(table)["pvalue", "1.treatment"]
        local ++counter_index
        mat def pvalue_index_`i'[`counter_index', 4] = r(table)["pvalue", "2.treatment"]
        local ++counter_index
    
        test 1.treatment = 2.treatment
        estadd scalar equals = r(p)
        estadd local ffx = "Yes"
        estadd scalar ar2 = e(r2_a)
    
        forval k = 0/2 {
            sum `depvar' if treatment == `k' & e(sample) == 1
            estadd scalar mean_`k' = r(mean)
            }
            }
            }
            }  


esttab foodext_* ///
    using "$csae/foodext.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Lean" "Endline") ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    posthead( ///
    \midrule ///
    \it{Food consumption} \\ ///
    \midrule ///
    ) ///
    replace
