****************************************************************************
* -------------- I. Create and prep "de-duplicated" files ---------------- *
****************************************************************************
clear
import excel "${baseline_raw_admin}/hfc_duplicates.xlsx", firstrow
keep if drop == "drop"
keep hhid key
rename key instance
tempfile baseline_drop
save "`baseline_drop'"

clear
use "${baseline_raw}/Niger 2022 - Shock Response.dta"
destring hhid, replace
drop if missing(hhid)
// duplicates tag hhid, gen(surveyed_twice)
// replace surveyed_twice = 1 if surveyed_twice > 0
keep hhid key
rename key instance

merge m:1 instance using "`baseline_drop'"
drop if _merge == 3
drop _merge
tempfile hhid_key_v19
save "`hhid_key_v19'", replace

local dta_files : dir "${baseline_raw}" files "*.dta"

foreach dta_file in `dta_files' {
    di "`dta_file'"
}

clear
use "${baseline_raw}/Niger 2022 - Shock Response-gp_consent-SECTION_transfers-rpt_trans.dta"


foreach dta_file in `dta_files' {

    display as error "`dta_file'"

    clear
    use "${baseline_raw}/`dta_file'"

    cap sum parent_key

if _rc == 0 {
    di "this is a long form dataset, with parent key and key"

    * first 41 characters are the instance/survey id
    gen instance = substr(parent_key, 1, 41)
    drop parent_key

    merge m:1 instance using "`hhid_key_v19'"
    keep if _merge == 3
    drop _merge

    drop instance
    destring hhid, replace
    order hhid, first

}

else {
    di "this is a wide form dataset"
    rename key instance

    destring hhid, replace
    order hhid, first

    merge m:1 hhid instance using "`hhid_key_v19'"
    keep if _merge == 3
    drop _merge

    order hhid, first

}

    capture drop *setof*
    capture drop start_*
    capture drop end_*
    capture drop instancename
    capture drop formdef_version
    capture drop starttime
    capture drop endtime

    capture drop setofrpt*
    capture drop setofbr*
    capture drop end_*
    capture drop start_*
    capture drop pull_rel_*

    capture drop pull_*
    capture drop age_mem*
    capture drop resp_santeeduc_*
    capture drop employment_hh_mems_*
    capture drop calc_strategy*u
    capture drop rpt*count

    duplicates drop

    capture drop if missing(activity1det)
    duplicates drop

    quietly {

    * destring all variables except "specify other"
    destring *, replace
    capture tostring *_o, replace

    * numeric variables: recode missing
    ds, not(type string)
    local numeric_var `r(varlist)'
    mvdecode `numeric_var', mv(-999 = .r) // refused
    mvdecode `numeric_var', mv(-888 = .d) // don't know
    mvdecode `numeric_var', mv(-777 = .o) // other
    mvdecode `numeric_var', mv(-666 = .n) // na
    mvdecode `numeric_var', mv(-555 = .g) // god or unknown relation
    mvdecode `numeric_var', mv(-333 = .m)
    mvdecode `numeric_var', mv(-222 = .r)
    mvdecode `numeric_var', mv(-111 = .i)

    *string variables: recode missing
    ds, has(type string)
    local string_var `r(varlist)'
    display "here"

    foreach var in `string_var' {
    replace `var' = "" if `var' == "-999" // refused
    replace `var' = "" if `var' == "-888" // don't know
    replace `var' = "" if `var' == "-777" // other
    replace `var' = "" if `var' == "-666" // na
    replace `var' = "" if `var' == "-555" // god or unknown relation
    }

    }

    *shorten variable labels for Stata 13
    foreach i of varlist _all {
    local longlabel: var label `i'
    local shortlabel = substr(`"`longlabel'"', 1, 79)
    label variable `i' `"`shortlabel'"'
    }
    save "${baseline_prepared}/`dta_file'", replace
}

*/
****************************************************************************
*--------------------- II. PREPARE HOUSEHOLD DATA -------------------------*
****************************************************************************


/*a. prep main file Niger 2022 - Shock Response.dta

    Input: Niger 2022 - Shock Response.dta; treatment_assignment.dta

    Output: niger_main_2021 ; identification.dta (subset of niger_main_2021)

*/

** Variable types changed during SurveyCTO import -- fix
clear
use "${baseline_prepared}/Niger 2022 - Shock Response.dta"
drop if missing(hhid)

tempfile main_file
save "`main_file'"

** country
gen country = "niger"
label variable country "country"

** ccode
gen ccode = "NER"
label variable ccode "Country code"

*locations
gen __UPDATED__ = "Updated location"


rename fu_village_code codevillage

gen village_ = codevillage

rename fu_commune_code commune_

rename fu_region_code region_

rename fu_department_code department_

* use hhid to merge with treatment status dataset
merge m:1 codevillage using "${dataWorkFolder}/treatment_assignment/treatment_assignment.dta", keepusing(treatment)
drop if _merge == 2
drop _merge

* note control group
label values treatment .
recode treatment (0 = 2) (2 = 0) (1 = 1)
label define treatment 0 "Traditional response" 1 "Early short" 2 "Early long", replace
label values treatment treatment

label variable shock1 "Drought"
label variable shock2 "Flood"
label variable shock3 "Crop disease"
label variable shock4 "Animal disease"
label variable shock5 "Increase in agri input prices"
label variable shock6 "Decrease in agri output prices"
label variable shock7 "Increase in food prices"
label variable shock8 "Loss of non-agri income"
label variable shock9 "Serious illness in HH"
label variable shock10 "Death of HH member"
label variable shock11 "Divorce"
label variable shock12 "Theft of money, goods"
label variable shock13 "Other shock"

save "${baseline_intermediate}/niger_main_2021.dta", replace

keep hhid consent country ccode treatment village_ commune_ region_ department_

keep if consent == 1
sort hhid

save "${baseline_intermediate}/identification.dta", replace

****************************************************************************
*----------------- III. PREPARE HOUSEHOLD MEMBER  DATA ------------------- *

*Input: Niger 2022 - Shock Response-gp_consent-SECTION_roster-rpt_mem.dta ; Niger 2022 - Shock Response-gp_consent-SECTION_members-rpt_mem2.dta

*Output: members_long.dta; members_wide.dta

****************************************************************************

// put both surveycto loops over members together in same file (rpt_mem and rpt_mem2)

// roster: name, age, sex, relation with household head, marital status
clear
use "${baseline_prepared}/Niger 2022 - Shock Response-gp_consent-SECTION_roster-rpt_mem.dta"

order hhid fu_mem_id add_new still_member posif_here posif_chef posif_spouse

drop if add_new == 0
drop if still_member == 0
drop if missing(posif_here)

split fu_mem_id, parse("-")
drop fu_mem_id1
destring fu_mem_id2, replace
rename fu_mem_id2 mem_pos
sort hhid mem_pos
order hhid fu_mem_id posif_here add_new mem_pos fu_relation_txt fu_relation_code relation is_chef posif_here posif_chef posif_spouse

replace mem_pos = posif_here if missing(mem_pos) & add_new == 1
assert posif_here == mem_pos
drop posif_here
drop add_new
drop fu_mem_id
order hhid mem_pos fu_relation_txt fu_relation_code relation is_chef posif_chef posif_spouse
sort hhid mem_pos, stable
label variable mem_pos "Position in Roster"

compress
distinct hhid

tempfile members
save "`members'"

*** roster: marital status, education level, physical state/wellbeing
clear
use "${baseline_prepared}/Niger 2022 - Shock Response-gp_consent-SECTION_members-rpt_mem2.dta"

** get position number of household member
gen mem_pos = hh_pos2
label variable mem_pos "Position in roster"
sort hhid mem_pos
order mem_pos, after(hhid)
drop if missing(hh_mm_age)

tempfile members2
save "`members2'"

use "`members'"
merge 1:1 hhid mem_pos using "`members2'"
order key, last

drop _merge
order mem_pos, after(hhid)

gen old_new = ""
order old_new, after(mem_pos)
label variable    old_new "preloaded member or new this round"


*** Labelling
gen __Preloaded__ = "Preloaded member information"

label variable fu_sex "Preloaded: sex"
label variable fu_age "Preloaded: age"
label variable fu_relation_code "Preloaded: relationship to preloaded household head"
label values fu_relation_code relation
drop fu_relation_txt
rename fu_relation_code fu_relation

label variable    still_member "Preloaded member is still a member of household"
label variable still_member_whynot "Why preloaded member not still a member of household"
label variable still_member_whynot_o "Other"

gen __Updated__ = "Updated member information"
order    __Updated__, before(still_member)
order is_chef, before(posif_chef)
label variable is_chef "Is household head"
rename posif_chef pos_chef
order relation_o, after(relation)
order rank_fem, after(relation_o)

label variable sex "Sex"
label variable age "Age"
label variable relation "Relation to household head"
label variable relation_o "Other"
label variable rank_fem "Seniority of wife"
label variable newmem_why "Why was this member not preloaded as a household member"
label variable pos_chef "Chef position if this member is household head"

*drop hh_mm_first hh_mm_age // only needed in SurveyCTO
*label variable hh_mm_key "Household head or beneficiary - key member for SurveyCTO"
label variable marital "Marital status"
label variable spouse_in "Is the spouse in the household"
label variable spouses "Who are the spouses in the household (roster position)"
label variable read "Can read"
label variable read_w "What languages can they read"
save "${baseline_intermediate}/members_long.dta", replace

** add a prefix for reshape
quietly ds hhid mem_pos, not
foreach var in `r(varlist)' {
    rename `var' `var'_
}

// quietly ds hhid mem_pos, not
// reshape wide `r(varlist)', i(hhid) j(mem_pos)
// save "${baseline_intermediate}/members_wide.dta", replace

* ------------------------------------------------------------------------ *
* ---------------------------- Prep Agriculture -------------------------- *
* ------------------------------------------------------------------------ *

/*

Input: Niger 2022 - Shock Response-gp_consent-SECTION_agriculture-SECTION_plot-rpt_plots.dta; Niger 2022 - Shock Response-gp_consent-SECTION_agriculture-SECTION_cropsrain1-rpt_plotrain.dta; Niger 2022 - Shock Response-gp_consent-SECTION_agriculture-SECTION_cropsdry1-rpt_plotdry.dta;

Output: main_plotlist_wide

*/

* ------------------------------- Plots ---------------------------------- *


/// Main plot list
clear
use "${baseline_prepared}/Niger 2022 - Shock Response-gp_consent-SECTION_agriculture-SECTION_plot-rpt_plots.dta"
sort hhid plot_pos

** generate key
gen __key__ = plot_pos
label variable __key__ "position in roster"
order __key__, after(hhid)

** clean strings
ds, has(type string)
foreach var in `r(varlist)' {
    replace `var' = trim(itrim(`var'))
}

** save
tempfile main_plotlist
save  `main_plotlist'

/// Rain plot list
clear
use "${baseline_prepared}/Niger 2022 - Shock Response-gp_consent-SECTION_agriculture-SECTION_cropsrain1-rpt_plotrain.dta"

drop if missing(rain_plot_name)

* convert variable type for append
quietly ds raincodeorother* rcropname*, has(type numeric)
foreach var in `r(varlist)' {
    tostring `var', replace
}

tempfile plotrain
save "`plotrain'", replace

** generate key
split key, parse([ ])
destring key2, gen(__key__)
label variable __key__ "position in roster"
order __key__, after(hhid)
drop key
sort hhid __key__

** ensure rcrop1_o - rcropname10 are strings
quietly ds rcrop1_o rcrop2_o rcrop3_o rcrop4_o rcrop5_o rcrop6_o rcrop7_o rcrop8_o rcrop9_o rcrop10_o, has(type numeric)
foreach var in `r(varlist)' {
    tostring `var', replace
}

** clean strings
ds, has(type string)
foreach var in `r(varlist)' {
    replace `var' = trim(itrim(`var'))
}

** save
tempfile main_rainplotlist
save "`main_rainplotlist'"


/// Merge main_rainplotlist
clear
use "`main_rainplotlist'"
tempfile merged_plotlist
save `merged_plotlist', replace

use `main_plotlist', clear
*double check merge
merge 1:1 hhid __key__ using `merged_plotlist'
drop _merge

** clean
drop if missing(plot_name)

tempfile main_plotlist_rain
save  `main_plotlist_rain'

/// Dry plot list
clear
use "${baseline_prepared}/Niger 2022 - Shock Response-gp_consent-SECTION_agriculture-SECTION_cropsdry1-rpt_plotdry.dta"

* convert variable type for append
quietly ds drycodeorother* dcropname*, has(type numeric)
foreach var in `r(varlist)' {
    tostring `var', replace
}

tempfile plotdry
save `plotdry'


** generate key
split key, parse([ ])
destring key2, gen(__key__)
label variable __key__ "position in roster"
order __key__, after(hhid)
drop key

sort hhid __key__

** ensure dcrop1_o - dcropname10 are strings
quietly ds dcrop1_o - dcropname10, has(type numeric)
foreach var in `r(varlist)' {
    tostring `var', replace
}

** clean strings
ds, has(type string)
foreach var in `r(varlist)' {
    replace `var' = trim(itrim(`var'))
}

** drop missing observations
drop if missing(dry_plot_name)

** save

tempfile main_dryplotlist
save `main_dryplotlist'

/// Merge main_dryplotlist and main_dryplotlist
use `main_dryplotlist', clear
tempfile merged_plotlist

save `merged_plotlist', replace
clear
use `main_plotlist_rain'

*double check merge
merge 1:1 hhid __key__ using `merged_plotlist'
drop _merge

** clean
drop if missing(plot_name)

** label variables
label variable plot_pos  "position dans la liste"
label variable plot_name  "parcelle"
label variable plot_ha  "taille de parcelle (hectares)"
label variable plot_key  "parcelle gere ou possede par la beneficiaire ou le chef du menage"
label variable plot_isdry  "dry plot"
label variable plotpos_isdryandkey "parcelle clef et pluviale"


forvalues i = 1/60 {
cap confirm var days_mem`i'
if !_rc{
label variable days_mem`i' "nombre de jours que personne `i' a travaille sur la parcelle"
}
}


forvalues i = 1/10 {
label variable raincodeorother`i'  "code ou nom de la culture - pluviale"
label variable rcropname`i'  "nom de la culture - pluviale"
}


    forvalues i = 1/10 {
label variable drycodeorother`i'  "code ou nom de la culture - pluviale"
label variable dcropname`i'  "nom de la culture - pluviale"
}

label variable rain_plot_name  "parcelle - pluviale"
label variable dry_plot_name  "parcelle - pluviale"
label variable plot_rain_grew  "les cultures cultives sur la parcelle pluviale"
label variable plot_rain_harv  "les cultures recoltes sur la parcelle pluviale"
label variable plot_rain_sold  "les cultures vendus sur la parcelle pluviale"
label variable plot_dry_harv  "les cultures recoltes sur la parcelle pluviale"
label variable plot_dry_sold  "les cultures vendus sur la parcelle pluviale"

* save long

save "${baseline_intermediate}/main_plotlist_long", replace

** reshape wide
quietly ds hhid plot_pos, not

foreach var in `r(varlist)' {
    rename `var' `var'_
    local l_`var'_ : variable label `var'_
}

quietly ds hhid plot_pos, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(plot_pos)   /// flag error

quietly ds plot_name_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1/`count' {
    foreach varstub in `stubnames' {
    di "display variable: `varstub'`i'"
    di "display label: `varstub'`i'"
    label variable `varstub'`i' "`l_`varstub''"

    }
}

** save wide

save "${baseline_intermediate}/main_plotlist_wide", replace

* ---------------------------- Rain Crops -------------------------------- *


/*
Input: Niger 2022 - Shock Response-gp_rainkeycond-rpt_rcrops.dta; Niger 2022 - Shock Response-gp_consent-SECTION_agriculture-SECTION_cropsrain2-rpt_rcrops2.dta;

Output: raincrops_1_long; raincrops_1_wide; raincrops_2_long; raincrops_2_wide
*/


/// Rain crops 1

use "${baseline_prepared}/Niger 2022 - Shock Response-gp_rainkeycond-rpt_rcrops.dta", clear

** generate plot and crop number using 'key' variable
split key, parse([ ])
destring key2, gen(plot_no)
destring key4, gen(crop_no)
order hhid plot_no crop_no, first
sort hhid plot_no crop_no
drop key key1 key2 key3 key4

** drop empty observations
drop if missing(rcrop_name)

** save temporary file

tempfile rain_crops_1
save `rain_crops_1', replace

/// Rain crops 2
use "${baseline_prepared}/Niger 2022 - Shock Response-gp_consent-SECTION_agriculture-SECTION_cropsrain2-rpt_rcrops2.dta", clear

** generate crop position (position in harvested crop list) from 'key' variable
split key, parse([ ])
destring key2, gen(crop_pos)
order hhid crop_pos, first
sort hhid crop_pos
drop key key1 key2

** drop empty observations
drop if missing(raincodeorother)
drop if raincodeorother == "."

** save temporary file

tempfile rain_crops_2
save `rain_crops_2', replace


/// MERGE

    // 1 - Produce final rain crops 1 dataset

*take 'crop_pos' variable from rcrops2 dataset to add into rcrops1 dataset
use `rain_crops_2', clear

keep hhid crop_pos rcrop2name

tempfile rcrop2_merge
save `rcrop2_merge'

use `rain_crops_1', clear

** generate linking variable, "rcrop2name"
gen rcrop2name = rcrop_name

** merge
merge m:1 hhid rcrop2name using `rcrop2_merge'
* _m = 1 when harvesting hadn't begun or if harvest was entirely lost. Drop if _m == 2.
drop if _merge == 2
drop _merge

order hhid plot_no crop_no crop_pos, first
sort hhid plot_no crop_no crop_pos

* This is the final "rainCrops_1" dataset

save "${baseline_intermediate}/raincrops_1_long", replace


** reshape wide
gen plot_crop_no = string(plot_no)+"_"+string(crop_no)

order plot_crop_no, after(crop_no)
drop plot_no crop_no


quietly ds hhid plot_crop_no, not
foreach var in `r(varlist)' {
    rename `var' `var'_
}

quietly ds hhid plot_crop_no, not

reshape wide `r(varlist)', i(hhid) j(plot_crop_no) string

* In the reshape, the first number in the suffix is the plot number.
* The second number in the suffix is the crop number


save "${baseline_intermediate}/raincrops_1_wide", replace


    // 2 - Produce final rain crops 2 dataset

* take 'plot_no' from rcrops1 and merge into rcrops2
use "${baseline_intermediate}/raincrops_1_long", clear

keep hhid rcrop_name plot_no

** reshape dataset
* want to reshape dataset into unique household-crop observations.
bysort hhid rcrop_name : gen n = _n
reshape wide plot_no , i(hhid rcrop_name) j(n)

** generate list of plots by crop
quietly ds plot_no*
foreach var in `r(varlist)' {
    tostring `var', replace
    replace `var' = "" if `var' == "."
}

quietly ds plot_no*
egen plot_no = concat(`r(varlist)'), punct(" ")

** save
keep hhid rcrop_name plot_no
rename rcrop_name rcrop2name
tempfile plot_no
save `plot_no', replace

** add plot_no to rcrops2
use  `rain_crops_2', clear

merge 1:1 hhid rcrop2name using `plot_no'
order  hhid crop_pos plot_no, first
* _m = 2 are crops that were not harvested/sold by the household and are therefore not in rcrops2
drop if  _merge == 2
drop  _merge

* This is the final rain Crops 2 dataset

save  "${baseline_intermediate}/raincrops_2_long", replace

* reshape wide
quietly ds hhid crop_pos, not
foreach var in `r(varlist)' {
    rename `var' `var'_
}

quietly ds hhid crop_pos, not
reshape  wide `r(varlist)', i(hhid) j(crop_pos)


save  "${baseline_intermediate}/raincrops_2_wide", replace

* ---------------------------- Dry Crops -------------------------------- *

/*

Input: Niger 2022 - Shock Response-gp_drykeycond-rpt_dcrops.dta; Niger 2022 - Shock Response-gp_consent-SECTION_agriculture-SECTION_cropsdry2-rpt_dcrops2.dta;

Output: drycrops_1_long; drycrops_1_wide ; drycrops_2_long; drycrops_2_wide

*/

//Drycrops 1

use "${baseline_prepared}/Niger 2022 - Shock Response-gp_drykeycond-rpt_dcrops.dta", clear

** generate plot and crop number using 'key' variable
split key, parse([ ])
destring key2, gen(plot_no)
destring key4, gen(crop_no)
order hhid plot_no crop_no, first
sort hhid plot_no crop_no
drop key key1 key2 key3 key4

** drop empty observations
drop if missing(dcrop_name)

** save temporary file

tempfile dry_crops_1
save `dry_crops_1', replace

/// Dry crops 2
use "${baseline_prepared}/Niger 2022 - Shock Response-gp_consent-SECTION_agriculture-SECTION_cropsdry2-rpt_dcrops2.dta", clear

** generate crop position (position in harvested crop list) from 'key' variable
split key, parse([ ])
destring key2, gen(crop_pos)
order hhid crop_pos, first
sort hhid crop_pos
drop key key1 key2

** drop empty observations
drop if missing(drycodeorother)
drop if drycodeorother == "."

** save temporary file

tempfile dry_crops_2
save `dry_crops_2', replace

/// MERGE

    // 1 - Produce final dry crops 1 dataset

*take 'crop_pos' variable from dcrops2 dataset to add into dcrops1 dataset
use `dry_crops_2', clear

keep hhid crop_pos dcrop2name

tempfile dcrop2_merge
save `dcrop2_merge'

use `dry_crops_1', clear

** generate linking variable, "dcrop2name"
gen dcrop2name = dcrop_name

** merge
merge m:1 hhid dcrop2name using `dcrop2_merge'
* _m = 1 when harvesting hadn't begun or if harvest was entirely lost. Drop if _m == 2.
drop if _merge == 2
drop _merge

order hhid plot_no crop_no crop_pos, first
sort hhid plot_no crop_no crop_pos

* This is the final "dryCrops_1" dataset

save "${baseline_intermediate}/drycrops_1_long", replace

** reshape wide
gen plot_crop_no = string(plot_no)+"_"+string(crop_no)

order plot_crop_no, after(crop_no)
drop plot_no crop_no


quietly ds hhid plot_crop_no, not
foreach var in `r(varlist)' {
    rename `var' `var'_
}

quietly ds hhid plot_crop_no, not

reshape wide `r(varlist)', i(hhid) j(plot_crop_no) string

save "${baseline_intermediate}/drycrops_1_wide", replace

// 2 - Produce final dry crops 2 dataset

* take 'plot_no' from dcrops1 and merge into dcrops2
use "${baseline_intermediate}/drycrops_1_long", clear

keep hhid dcrop_name plot_no

** reshape dataset
* want to reshape dataset into unique household-crop observations.
bysort hhid dcrop_name : gen n = _n
reshape wide plot_no , i(hhid dcrop_name) j(n)

** generate list of plots by crop
quietly ds plot_no*
foreach var in `r(varlist)' {
    tostring `var', replace
    replace `var' = "" if `var' == "."
}

quietly ds plot_no*
egen plot_no = concat(`r(varlist)'), punct(" ")

** save
keep hhid dcrop_name plot_no
rename dcrop_name dcrop2name
tempfile plot_no
save `plot_no', replace

** add plot_no to dcrops2
use  `dry_crops_2', clear


merge 1:1 hhid dcrop2name using `plot_no'
order  hhid crop_pos plot_no, first
* _m = 2 are crops that were not harvested/sold by the household and are therefore not in dcrops2
drop if  _merge == 2
drop  _merge

* This is the final dry Crops 2 dataset

save  "${baseline_intermediate}/drycrops_2_long", replace

** reshape wide
quietly ds hhid crop_pos, not
foreach var in `r(varlist)' {
    rename `var' `var'_
}


/*    *Chage when have duplicates file from survey team
unab vlist : hhid crop_pos

sort `vlist'

quietly by `vlist':  gen dup = cond(_N==1,0,_n)

browse if dup>0

drop if dup>0

drop dup
*/
quietly ds hhid crop_pos, not
reshape  wide `r(varlist)', i(hhid) j(crop_pos)


save  "${baseline_intermediate}/drycrops_2_wide", replace

* ------------------------------------------------------------------------ *
* ----------------------------- Prep Assets ------------------------------ *
* ------------------------------------------------------------------------ *



* ------------------------ Agricutural Assets ---------------------------- *

/*

Input: Niger 2022 - Shock Response-gp_consent-SECTION_assets-rpt_ag_ass.dta;

Output: assets_ag_long; assets_ag_wide

*/


use "${baseline_prepared}/Niger 2022 - Shock Response-gp_consent-SECTION_assets-rpt_ag_ass.dta", clear
sort hhid ag_ass_pos

** generate key
split key, parse([ ])
destring key2, gen(__key__)
label variable __key__ "position in roster"
drop key key1 key2
order __key__, after(ag_ass_pos)

compare __key__ ag_ass_pos
** equal

drop __key__
sort hhid ag_ass_pos

** rename variables to be consistent
rename ass_ag ag_asset
rename ass_ag_n ag_asset_n
rename ag_ass_name ag_asset_name

** save long

save "${baseline_intermediate}/assets_ag_long", replace

*Chage when have duplicates file from survey team
/* unab vlist : hhid ag_ass_pos

sort `vlist'

quietly by `vlist':  gen dup = cond(_N==1,0,_n)

browse if dup>0

drop if dup>0

drop dup
*/
** reshape wide
quietly ds hhid ag_ass_pos, not
foreach var in `r(varlist)' {
    rename `var' `var'_
    local l_`var'_ : variable label `var'_
}

quietly ds hhid ag_ass_pos, not
local stubnames "`r(varlist)'"

reshape wide `r(varlist)', i(hhid) j(ag_ass_pos)

quietly ds ag_asset_name_*
local count = wordcount("`r(varlist)'")
display    "`count'"

forvalues i = 1 / `count' {
    foreach varstub in `stubnames' {
    display "display variable: `varstub'`i'"
    display "display label: `varstub'`i'"
    label variable `varstub'`i' "`l_`varstub''"
    }
}


save "${baseline_intermediate}/assets_ag_wide", replace

* ------------------------- Household Assets ----------------------------- *

/*

Input: Niger 2022 - Shock Response-gp_consent-SECTION_assets-rpt_hh_ass.dta

Output: assets_hh_long; assets_hh_wide

*/

use "${baseline_prepared}/Niger 2022 - Shock Response-gp_consent-SECTION_assets-rpt_hh_ass.dta", clear

** generate key
split key, parse([ ])
destring key2, gen(__key__)
label variable    __key__ "position in roster"
drop key key1 key2
order __key__, after(ass_hh_pos)

compare __key__ ass_hh_pos

** equal
drop __key__
sort hhid ass_hh_pos


** rename variables to be consistent
rename ass_hh* hh_asset*


save "${baseline_intermediate}/assets_hh_long", replace

*Chage when have duplicates file from survey team
/*   unab vlist : hhid hh_asset_pos

sort `vlist'

quietly by `vlist':  gen dup = cond(_N==1,0,_n)

browse if dup>0

drop if dup>0

drop dup
*/
** reshape wide, then save labels for after reshape
quietly ds hhid hh_asset_pos, not
foreach var in `r(varlist)' {
    rename `var' `var'_
    local l_`var'_ : variable label `var'_
}

quietly ds hhid hh_asset_pos, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(hh_asset_pos)

quietly ds hh_asset_name_*
local count = wordcount("`r(varlist)'")
display "`count'"

forvalues i = 1 / `count' {
    foreach varstub in `stubnames' {
    display "display variable: `varstub'`i'"
    display "display label: `varstub'`i'"
    label variable `varstub'`i' "`l_`varstub''"
    }
}


save "${baseline_intermediate}/assets_hh_wide", replace



* ------------------------------------------------------------------------ *
* --------------------------- Prep Employment ---------------------------- *
* ------------------------------------------------------------------------ *



************ ------------------_ BENEFICIARIES  -------------- *************
****************************************************************************



* ----------------------------- 1. Work  --------------------------------- *

/*

Input: Niger 2022 - Shock Response-gp_consent-SECTION_emploi-rpt_wrk.dta; Niger 2022 - Shock Response-gp_consent-SECTION_emploi-rpt_empl

Output: work.dta; empl.dta

*/

use "${baseline_prepared}/Niger 2022 - Shock Response-gp_consent-SECTION_emploi-rpt_wrk.dta", clear

* keeping only employment section variables:
keep hhid key wrk_key_pos wrk_ag30 wrk_ag12 wrk_liv30 wrk_liv12 wrk_sal30 wrk_sal12 wrk_sal_n wrk_sal wrk_na30 wrk_na12

order hhid key, first
sort hhid


// label
label variable wrk_sal "Emploi salarié"

** save long

tempfile work
save `work', replace

save "${baseline_intermediate}/work.dta", replace


use "${baseline_prepared}/Niger 2022 - Shock Response-gp_consent-SECTION_emploi-rpt_empl", clear

keep hhid empl1 empl2 empl3 empl4 empl5 resp_empl short_work_duration short_work_duration_u short_work_amt short_work resp_empl key empl_key_work_n empl_key_worked empl_key_rpos empl_key_pos


foreach var in empl1 empl2 empl3 empl4 empl5 {
tostring `var', replace
replace `var' = "" if `var' == "."
}

** save long

tempfile empl
save `empl', replace

save "${baseline_intermediate}/empl.dta", replace


* ------------------- 2. Employment & Salary  ----------------------------- *

/*

Input: Niger 2022 - Shock Response-gp_empl_cond-rpt_sal.dta

Output: salary_long

*/

use "${baseline_prepared}/Niger 2022 - Shock Response-gp_empl_cond-rpt_sal.dta", clear



** generate key
split key, parse([ ])
drop key1 key3
destring key2 key4, replace

assert    key4 == empl_pos

// drop
drop key

// order
order hhid key2 empl_pos
sort hhid key2 empl_pos

rename key2 mem_pos

** label variables
label variable  empl_type "Type d'Emploi"
label variable mem_pos "Position of Household Member"

save "${baseline_intermediate}/salary_long", replace


* ------------------------------------------------------------------------ *
* ----------------------------- Prep Finance ----------------------------- *
* ------------------------------------------------------------------------ *



* ------------------------------- Credit  -------------------------------- *

    /*

Input: Niger 2022 - Shock Response-gp_consent-SECTION_finance-PART_credit-rpt_cred.dta

Output: credit_long; credit_wide

*/


use  "${baseline_prepared}/Niger 2022 - Shock Response-gp_consent-SECTION_finance-PART_credit-rpt_cred.dta", clear
sort hhid cred_pos

** generate key
split key, parse([ ])
destring key2, gen(__key__)
label variable __key__ "position in roster"
drop key key1 key2
order __key__, after(*_pos)

compare __key__ *_pos
** equal
drop *_pos
sort hhid __key__

** gen cred_name_o & label cred_name when cred_pos == 7
gen cred_name_o = cred_name if __key__ == 7
order cred_name_o, after(cred_name)
replace cred_name = "Autre personne ou groupe a specifier" if __key__ == 7

** save long

save "${baseline_intermediate}/credit_long", replace

** reshape wide
quietly ds hhid __key__, not

foreach var in `r(varlist)' {
    rename `var' `var'_
    local l_`var'_ : variable label `var'_
}


quietly ds hhid __key__, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(__key__)

quietly ds cred_name_o_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1/`count' {
    foreach varstub in `stubnames' {
    di "display variable: `varstub'`i'"
    di "display label: `varstub'`i'"
    label variable `varstub'`i' "`l_`varstub''"
    }
}

** save wide

save "${baseline_intermediate}/credit_wide", replace


* ------------------------------ Savings  -------------------------------- *

/*

Input: Niger 2022 - Shock Response-gp_consent-SECTION_finance-PART_othersave-gp_savemoreinfo.dta

Output: savings_long; savings_wide

*/

use "${baseline_prepared}/Niger 2022 - Shock Response-gp_consent-SECTION_finance-PART_othersave-gp_savemoreinfo.dta", clear
sort hhid saves_pos

** generate key
split key, parse([ ])
destring key2, gen(__key__)
label variable __key__ "position in roster"
drop key key1 key2
order __key__, after(saves_pos)

compare __key__ saves_pos
** equal
drop *_pos
sort hhid __key__

** gen saves_loc_name_o
gen saves_loc_name_o = saves_loc_name if __key__ == 9
order saves_loc_name_o, after(saves_loc_name)
replace saves_loc_name = "Autre endroit a specifier" if __key__ == 8

** save long

save "${baseline_intermediate}/savings_long", replace

** reshape wide
quietly ds hhid __key__, not

foreach var in `r(varlist)' {
    rename `var' `var'_
    local l_`var'_ : variable label `var'_
}

quietly ds hhid __key__, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(__key__)

quietly ds saves_loc_name_o_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1/`count' {
    foreach varstub in `stubnames' {
    di "display variable: `varstub'`i'"
    di "display label: `varstub'`i'"
    label variable `varstub'`i' "`l_`varstub''"
    }
}

** save wide

save "${baseline_intermediate}/savings_wide", replace

* ------------------------------------------------------------------------ *
* --------------------------- Prep Consumption --------------------------- *
* ------------------------------------------------------------------------ *



* --------------------------- Food Consumption --------------------------- *

/*

Input: Niger 2022 - Shock Response-gp_consent-SECTION_foodconsumption-rpt_consum2.dta ; Niger 2022 - Shock Response-gp_consent-SECTION_foodconsumption-rpt_consum1.dta

Output: foodconsumption_wide; foodconsumption_long

*/


clear
use "${baseline_prepared}/Niger 2022 - Shock Response-gp_consent-SECTION_foodconsumption-rpt_consum2.dta"
sort hhid consum2_pos, stable
order hhid consum2_pos

tempfile consum2
save "`consum2'", replace

use "${baseline_prepared}/Niger 2022 - Shock Response-gp_consent-SECTION_foodconsumption-rpt_consum1.dta", clear
sort hhid consum1_pos, stable

keep hhid consum1_pos consum1_name consum

** rename for merge
rename consum1_pos consum2_pos
duplicates drop
merge 1:m hhid consum2_pos using "`consum2'"
list hhid consum2_pos if _merge != 3
drop _merge

** generate key
// split key, parse([ ])
// destring key2, gen(food_loop)
// sort hhid food_loop
// order    food_loop, after(hhid)
// drop parent_key key key1 key2

** rename variables
rename *consum2_* *consum_*

** reshape wide
ds hhid consum_pos, not

foreach var in `r(varlist)' {
    rename `var' `var'_
    local l_`var'_ : variable label `var'_
}

duplicates drop hhid consum_pos, force
quietly ds hhid consum_pos, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(consum_pos)

quietly ds consum_name_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
    foreach varstub in `stubnames' {
    di "display variable: `varstub'`i'"
    di "display label: `varstub'`i'"
    label variable `varstub'`i' "`l_`varstub''"
    }
}

/* Not relevant in our case.
** add missing info where loops were messed up
replace consum_qty_18 = .m if hhid == 5878
replace consum_u_18 = .m if hhid == 5878
replace consum_prod_18 = .m if hhid == 5878
replace consum_gift_18 = .m if hhid == 5878
replace consum_bot_freq_18 = .m if hhid == 5878
replace gp_consum_bot_18 = .m if hhid == 5878
replace consum_bot_u_18 = .m if hhid == 5878
replace consum_bot_val_18 = .m if hhid == 5878
replace consum_u_bot_name_18 = "" if hhid == 5878
*/

**save wide

save "${baseline_intermediate}/foodconsumption_wide.dta", replace

**reshape back to long
reshape long
rename *_ *

save "${baseline_intermediate}/foodconsumption_long.dta", replace


* ------------------------- Non-Food Consumption ------------------------- *

/*
Input: Niger 2022 - Shock Response-gp_consent-SECTION_nfconsumption-gp_cel-rpt_cel1.dta ; Niger 2022 - Shock Response-gp_consent-SECTION_nfconsumption-gp_cel-rpt_cel2.dta ; Niger 2022 - Shock Response-gp_consent-SECTION_nfconsumption-gp_nonfood-rpt_nonfood.dta

Output: nf_celebrations_long; nf_celebrations_wide; nonfood_consumption_long; nonfood_consumption_wide

*/

/// celebrations 1

use  "${baseline_prepared}/Niger 2022 - Shock Response-gp_consent-SECTION_nfconsumption-gp_cel-rpt_cel1.dta", clear
sort hhid cel1_pos

** generate key
split key, parse([ ])
destring key2, gen(__key__)
label variable __key__ "position in roster"
drop key key1 key2
order __key__, after(cel1_pos)

compare __key__ cel1_pos
** equivalent
drop cel1_pos
sort hhid __key__

** save

tempfile cel1
save `cel1', replace

/// celebrations 2

use "${baseline_prepared}/Niger 2022 - Shock Response-gp_consent-SECTION_nfconsumption-gp_cel-rpt_cel2.dta", clear
sort hhid cel2_pos

** generate key
split key, parse([ ])
destring key2, gen(__key__)
label variable __key__ "position in roster"
drop key key1 key2
order __key__, after(cel2_pos)

compare cel2_pos __key__
** equivalent

sort hhid __key__

** save

tempfile cel2
save    `cel2', replace

** MERGE
use `cel1', clear
merge 1:1 hhid __key__ using `cel2'
drop _merge

** save long

save "${baseline_intermediate}/nf_celebrations_long", replace

** reshape wide
quietly ds hhid __key__, not

foreach var in `r(varlist)' {
    rename `var' `var'_
    local l_`var'_ : variable label `var'_
}


quietly ds hhid __key__, not

local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(__key__)

quietly ds cel_food_*

local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1/`count' {
    foreach varstub in `stubnames' {
    di "display variable: `varstub'`i'"
    di "display label: `varstub'`i'"
    label variable `varstub'`i' "`l_`varstub''"
    }
}

** save wide

save "${baseline_intermediate}/nf_celebrations_wide", replace




/// Non-food consumption

use "${baseline_prepared}/Niger 2022 - Shock Response-gp_consent-SECTION_nfconsumption-gp_nonfood-rpt_nonfood.dta", clear
sort hhid nonfood_pos

** generate key
split key, parse([ ])
destring key2, gen(__key__)
label variable __key__ "position in roster"
drop key key1 key2
order __key__, after(nonfood_pos)

compare __key__ nonfood_pos
** equal
drop nonfood_pos
sort hhid __key__


** clean string variables
ds, has(type string)

foreach var in `r(varlist)' {
    replace `var' = trim(itrim(`var'))
}

** save long

save "${baseline_intermediate}/nonfood_consumption_long", replace

** reshape wide
quietly ds hhid __key__, not

foreach var in `r(varlist)' {
    rename `var' `var'_
    local l_`var'_ : variable label `var'_
}


quietly ds hhid __key__, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(__key__)

quietly ds nonfood_name_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1/`count' {
    foreach varstub in `stubnames' {
    di "display variable: `varstub'`i'"
    di "display label: `varstub'`i'"
    label variable `varstub'`i' "`l_`varstub''"
    }
}


** save wide

save "${baseline_intermediate}/nonfood_consumption_wide", replace


* ------------------------------------------------------------------------ *
* ---------------------------- Prep Livestock ---------------------------- *
* ------------------------------------------------------------------------ *


/*

Input: Niger 2022 - Shock Response-gp_consent-SECTION_livestock-gp_haslivestock-rpt_ani1.dta; Niger 2022 - Shock Response-gp_consent-SECTION_livestock-gp_haslivestock-r_four.dta

Output: livestock_long; livestock_wide; livestock_mem_wrk_long; livestock_mem_wrk_wide

*/

use "${baseline_prepared}/Niger 2022 - Shock Response-gp_consent-SECTION_livestock-gp_haslivestock-rpt_ani1.dta", clear
sort hhid ani1_pos


** generate key
split key, parse([ ])
destring key2, replace


** compare ani1_pos key2


** drop variables
drop key key1 key2


** rename variables
rename ani1_pos livestock_pos



save "${baseline_intermediate}/livestock_long", replace


** reshape wide, then save labels for after reshape
quietly ds hhid livestock_pos, not
foreach var in `r(varlist)' {
    rename `var' `var'_
    local l_`var'_ : variable label `var'_
}

quietly ds hhid livestock_pos, not
local stubnames "`r(varlist)'"
reshape wide `stubnames', i(hhid) j(livestock_pos)

quietly ds ani1_name_*
local count = wordcount("`r(varlist)'")
display "`count'"

forvalues i = 1/`count' {
    foreach varstub in `stubnames' {
    display "display variable: `varstub'`i'"
    display "display label: `varstub'`i'"
    label variable `varstub'`i' "`l_`varstub''"
    }
}


save "${baseline_intermediate}/livestock_wide", replace


use "${baseline_prepared}/Niger 2022 - Shock Response-gp_consent-SECTION_livestock-gp_haslivestock-r_four.dta", clear

*???
*keywork, key_var(key) newkey_var(myliv_mm_pos) pos_var(liv_mm_pos) // one broken loop
*assert myliv_mm_pos == liv_mm_pos if liv_mm_pos != .
*drop myliv_mm_pos


foreach var of varlist liv_mm_age - betail_heures {
    assert `var' == . if liv_mm_pos == .
}

drop if liv_mm_pos == .
isid hhid liv_mm_pos
sort hhid liv_mm_pos


save "${baseline_intermediate}/livestock_mem_wrk_long", replace

// reshape wide

quietly ds hhid liv_mm_pos, not

foreach var in `r(varlist)' {
    rename `var' `var'_
    local l_`var'_ : variable label `var'_
}


quietly ds hhid liv_mm_pos, not
reshape wide `r(varlist)', i(hhid) j(liv_mm_pos)


save "${baseline_intermediate}/livestock_mem_wrk_wide", replace

* ------------------------------------------------------------------------ *
* ---------------------------- Prep Business ------------------------------
* ------------------------------------------------------------------------ *

*Input:

**Niger 2022 - Shock Response-gp_consent-SECTION_na-rpt_agr_enum.dta ; Niger 2022 - Shock Response-rpt_activitylist.dta

*Output: niger_business ; business_long; business_wide


use "${baseline_prepared}/Niger 2022 - Shock Response-gp_consent-SECTION_na-rpt_agr_enum.dta", clear

sort hhid agr_key_pos

* activities at individual level: remove non-key respondents
drop if bus1_food == .

egen bus_d = anymatch(bus1_food - bus1_extra), v(1)

foreach v in bus1_food bus1_tail bus1_constr bus1_comm bus1_prof bus1_serv bus1_trans bus1_art bus1_extra {
replace bus_d = 1 if `v' > 0
}


* cleaning business positions:


#delimit ;
label define business_types
1 "food"
2 "tail"
3 "constr"
4 "comm"
5 "prof"
6 "serv"
7 "trans"
8 "art"
9 "other";
#delimit cr

save "${baseline_intermediate}/niger_business.dta", replace


*****************************

clear
use "${baseline_prepared}/Niger 2022 - Shock Response-rpt_activitylist.dta"
sort hhid agrd_key_rpos
order hhid, before(act_pos)
order agrd_key_rpos, after(act_pos)



* dropping empty observations:
drop if bus2_name == ""

* dropping empty variables
forval i = 4/15{
    drop activity`i'det
    }

** generate key
split key, parse([ ])
destring key2 key4, replace

*compare key2 agrd_key_rpos
assert agrd_key_rpos == key2
* compare key4 and act_pos
assert act_pos == key4


** drop variables
drop key key*

** transform bus2_name
replace bus2_name = trim(itrim(lower(bus2_name)))


** label
label variable hhid "Household ID"
label variable act_pos "Business position"
label variable bus2_name "Business name"
label variable bus2_own "Business owner"
label variable bus2_workers "Household members working in business"

forvalues i = 1/50 {
    label variable actdays_mem`i' "Days member `i' worked in the household enterprise (last 30 days)"
}

label variable bus2_years "Number of years enterprise has been operational"
label variable bus2_mos12 "Months in the past year the enterprise has been operational"
label variable bus2_rev30 "Enterprise revenue in the past 30 days"
label variable bus2_pro30 "Enterprise profits in the past 30 days"
*label variable bus2_ass "Enterprise owns productive assets"
label variable bus2_assval "Value of owned assets"
label variable resp_bus2 "Respondant for this section of the questionnaire"


** save
duplicates drop // one repeat

save "${baseline_intermediate}/business_long", replace



* ------------------------------------------------------------------------ *
* ---------------------------- Prep Transfers ---------------------------- *
* ------------------------------------------------------------------------ *

/*

Input: Niger 2022 - Shock Response-gp_consent-SECTION_transfers-rpt_trans.dta ; Niger 2022 - Shock Response-gp_consent-SECTION_transfers-rpt_trans_send.dta

Output: transfers_long.dta; transfers_sent_long.dta

*/

use "${baseline_prepared}/Niger 2022 - Shock Response-gp_consent-SECTION_transfers-rpt_trans.dta", clear

order key, last
split key, parse([ ])
drop key key1
destring key2, gen(trans_pos2)
drop key2
label variable trans_pos2 "Location Position"
sort hhid trans_pos2
order hhid trans_pos2
assert trans_pos == trans_pos2
drop trans_pos

label variable trans_who "19.04 Transfer: Who is the beneficiary of this transfer?"
label variable trans_rel "19.05 For the sender, what is the relationship with the beneficiary?"
label variable trans_why "19.06 What is the main reason for the transfer?"
label variable trans_invill "19.06b Does the sender live in this village / neighborhood?"
label variable trans_why_o "What other reason?"
label variable trans_amt "19.07 What is the amount of the transfer sent each time?"
label variable trans_freq "If irregular, use last transfer and choose irregular frequency"


save "${baseline_intermediate}/transfers_long.dta", replace

***** Finance (transfers sent)

use "${baseline_prepared}/Niger 2022 - Shock Response-gp_consent-SECTION_transfers-rpt_trans_send.dta", clear

order key, last
split key, parse([ ])
drop key key1
destring key2, gen(trans_pos_send2)
drop key2
label variable trans_pos_send2 "Location Position"
sort hhid trans_pos_send2
order hhid trans_pos_send2
// assert trans_pos_send == trans_pos_send2 // hhid 266332 has broken loop. No reported transfers anyway
// br if trans_pos_send != trans_pos_send2
drop trans_pos_send2

label variable trans_who_send "19.1: Who is the sender of this transfer?"
label variable trans_rel_send "19.11 For containers outside the household, what is the relationship with the sender?"
label variable trans_why_send "19.12 What is the main reason for the transfer?"
label variable trans_send_invill "19.12b Does the beneficiary live in this village / neighborhood?"
label variable trans_why_o_send "What other reason?"
label variable trans_amt_send "19.13 What is the amount of the transfer sent each time"
label variable trans_freq_send "If irregular, use last transfer and choose irregular frequency"

save "${baseline_intermediate}/transfers_sent_long.dta", replace
