
/*

* Input:members_long.dta; niger_main_2021

* Output:demographics

* BASED ON: Sahel ASP Cleaning Code by Jarret Angbazo and Kelsey Wright

*/
clear
use "${baseline_intermediate}/members_long.dta"

** merging with main dataset in order to identify hhid to be dropped because not surveyed (using consent variable)
merge m:1 hhid using "${baseline_intermediate}/niger_main_2021.dta", keepus(hh_size_actual consent) gen(merge_main)
drop if consent == 0

* ensure that all observations were matched
assert merge_main == 3
drop merge_main

* making sure that every household has a household head
sort hhid, stable
by hhid : egen has_chef = total(is_chef)
assert has_chef == 1
gen chef_pos = mem_pos if is_chef == 1
sort hhid chef_pos, stable
by hhid : replace chef_pos = chef_pos[_n - 1] if missing(chef_pos)

** mem_n household size
sort hhid, stable
by hhid : gen mem_n = _N
label var mem_n "Number of members in household"

** adult_n
gen adult = (age >= 15 & age < .)
byso hhid : egen adult_n = total(adult)
label var adult_n "Number of adults age 15+ in household"
assert adult_n <= mem_n

** workage_n
gen workage = (age >= 15 & age <= 65)
byso hhid : egen workage_n = total(workage)
label var workage_n "Number of adults age 15-65 in housheold"
assert workage_n <= mem_n


** child_n
gen child = (age <= 14)
byso hhid : egen child_n = total(child)
label var child_n "Number of children age 0-14 in household"
assert child_n <= mem_n


** earlychild_n
gen earlychild = (age >=0 & age <= 5)
byso hhid : egen earlychild_n = total(earlychild)
label var earlychild_n "Number of children age 0-5 in household"
assert earlychild_n <= child_n


** oldchild_n
gen olderchild = (age >= 6 & age <= 14)
byso hhid : egen olderchild_n = total(olderchild)
label var olderchild_n "Number of children age 6-14 in household"
assert olderchild_n <= child_n


** elder_n
gen elder = (age >= 66 & age <.)
byso hhid : egen elder_n = total(elder)
label var elder_n "Number of adults age 66+ in household"
assert elder_n <= adult_n

** equiv_n:
gen equiv_n = 1+ ((adult_n-1)*0.7) + (0.5*(child_n))
label variable equiv_n "Adult equivalents"
assert equiv_n <= mem_n

// assertions on household size
*assert adult_n + child_n == mem_n  // 53 contradictions to assertion
assert earlychild_n + olderchild_n == child_n
assert elder_n + workage_n == adult_n



** depend
gen depend = (mem_n - workage_n)/mem_n
label var depend "Dependency ratio"

** extended
replace relation_o = trim(itrim(lower(relation_o)))
label copy relation relation_extend

/*
#delimit;
label define relation_extend
18 "tante/oncle"
19 "frère/soeur de conjoint"
, add;
#delimit cr
*/

gen relation_recode = relation, after(relation_o)
label val relation_recode relation_extend

gen ext = (relation_recode >= 6 & relation_recode < .)
byso hhid : egen extended = max(ext)
label var extended "Household contains extended family members"

** extend_share
by hhid : egen xt_share = total(ext)
gen extend_share = xt_share/mem_n
label var extend_share "Share of extended family members in the household"


** hhh_fem
gen hh_fem = 0
replace hh_fem = 1 if (sex == 1 & is_chef == 1)
bysort hhid : egen hhh_fem = max(hh_fem)
label var hhh_fem "Household head is female"
drop hh_fem

** hhh_age
gen hhh_age = age if is_chef == 1
sort hhid hhh_age, stable
by hhid : replace hhh_age = hhh_age[_n - 1] if missing(hhh_age) & !missing(hhh_age[_n - 1])
label var hhh_age "Household head age"


** poly
gen poly_d = 0
replace poly_d = 1 if is_chef == 1 & marital == 3
byso hhid : egen poly = max(poly_d)
label var poly "Polygamous head of household or CT beneficiary"
drop poly_d

*** poly_hhh_fem
gen poly_hh_fem = 0
replace poly_hh_fem = 1 if (is_chef == 1 & marital == 3 & sex == 1)
byso hhid : egen poly_hhh_fem = max(poly_hh_fem)
label var poly_hhh_fem "Polygamous female household head"
drop poly_hh_fem

*** poly_hhh_mal
gen poly_hh_mal = 0
replace poly_hh_mal = 1 if (is_chef == 1 & marital == 3 & sex == 0)
byso hhid : egen poly_hhh_mal = max(poly_hh_mal)
label var poly_hhh_mal "Polygamous male household head"
drop poly_hh_mal

/* I start counting years of education from Primaire. Garderie/Jardin des Enfants is assigned to
zero years of education */


** hhh_edu
gen hh_edu = 0
replace hh_edu = (edu_lvl-1) if is_chef == 1
replace hh_edu = 0 if hh_edu < 0
replace hh_edu = 0 if missing(hh_edu) & edu == 0
byso hhid : egen hhh_edu = max(hh_edu)
label var hhh_edu "Household head years of education"
drop hh_edu

** hhh_noeduc
gen hhh_noeduc = 0
replace hhh_noeduc = 1 if hhh_edu == 0
label var hhh_noeduc "Household head has no years of education"

** hhh_prim
gen hhh_prim = 0
replace hhh_prim = 1 if hhh_edu >= 7 & !missing(hhh_edu)
label var hhh_prim "Household head completed primary school"


** hhh_lit
gen hh_lit = 0
replace hh_lit = 1 if (is_chef == 1 & read == 1)
byso hhid : egen hhh_lit = max(hh_lit)
label var hhh_lit "Household head is literate"
drop hh_lit


** child_school
gen tag_child_school = ((age >= 6 & age <= 14) & edu_now == 1)
byso hhid : egen count_child_school = total(tag_child_school)
gen child_school = count_child_school / olderchild_n
replace child_school = 0 if olderchild_n == 0
label var child_school "Proportion of children aged 6-14 in school"

** girl_school
gen tag_girl_school = ((age >= 6 & age <= 14) & edu_now == 1 & sex == 1)
byso hhid : egen count_girl_school = total(tag_girl_school)
byso hhid : egen girl_n = total(olderchild & sex == 1)
gen girl_school = count_girl_school / girl_n
replace girl_school = 0 if girl_n == 0
label var girl_school "Proportion of girls aged 6-14 in schoool"

** boy_school
gen tag_boy_school = ((age >= 6 & age <= 14) & edu_now == 1 & sex == 0)
byso hhid : egen count_boy_school = total(tag_boy_school)
byso hhid : egen boy_n = total(olderchild & sex == 0)
gen boy_school = count_boy_school / boy_n
replace boy_school = 0 if boy_n == 0
label var boy_school "Proportion of boys aged 6-14 in schoool"


** household members sleeping away from household

*change any answers longer than 30 days to be the max of 30 nights
replace sleep_n=. if missing(sleep_u)
replace sleep_n = 30 if sleep_n>30 & !missing(sleep_n) & sleep_u==1 //nights
replace sleep_n = 30/7 if sleep_n>4 & !missing(sleep_n) & sleep_u==2 //weeks
replace sleep_n = 1 if sleep_n>1 & !missing(sleep_n) & sleep_u==3 //months

*Recode number of nights slept away from household to be in nights
gen sleep_n_std = sleep_n if sleep_u==1
replace sleep_n_std=7*sleep_n if sleep_u==2
replace sleep_n_std=30*sleep_n if sleep_u==3
label var sleep_n_std "number of nights household member slept away from the household"

*recode sleep why so that other is its own cateogry

replace sleep_why=11 if sleep_why==.o


*gen variables by reason for sleeping away from household
gen mm_away_study = sleep_n_std if sleep_why==1
 label var mm_away_study "slept away from the household to study"

 gen mm_away_ill = sleep_n_std if sleep_why==2
 label var mm_away_ill "slept away from the household due to disease or hosiptal stay"

 gen mm_away_vfam = sleep_n_std if sleep_why==3
 label var mm_away_vfam "slept away from the household due to visiting family"

gen mm_away_mrkt = sleep_n_std if sleep_why==4
label var mm_away_mrkt"slept away from the household due to going to market"

gen mm_away_busi = sleep_n_std if sleep_why==5
label var mm_away_busi "slept away from the household due to small business"

gen mm_away_agri = sleep_n_std if sleep_why==6
label var mm_away_agri "slept away from the household due to agricultural work"

gen mm_away_ahus = sleep_n_std if sleep_why==7
label var mm_away_ahus "slept away from the household due to work in animal husbandry"

gen mm_away_ming = sleep_n_std if sleep_why==8
label var mm_away_ming "slept away from the household due to mining"

gen mm_away_owrk = sleep_n_std if sleep_why==9
label var mm_away_owrk "slept away from the household due to other work"

gen mm_away_afam = sleep_n_std if sleep_why==10
label var mm_away_afam "slept away from the household to accompany family"

gen mm_away_other = sleep_n_std if sleep_why==11
label var mm_away_other "slept away from the household due to non specified reason"

gen mm_away_work = sleep_n_std if sleep_why==5 | sleep_why==6 | sleep_why==7 | sleep_why==8 | sleep_why==9
label var mm_away_work "slept away from the household due to work "

*agregate to household level

byso hhid: egen away = total(sleep_n_std) , missing
label var away "average days household members slept away"

byso hhid: egen away_work = total(mm_away_work) , missing
label var away_work "average days household members slept away due to work"

// clean

order hhid hhh_fem poly poly_hhh_fem poly_hhh_mal ///
hhh_age  hhh_edu  hhh_prim   ///
hhh_noeduc hhh_lit

order mem_n equiv_n adult_n workage_n child_n earlychild_n olderchild_n  ///
elder_n depend child_school girl_school, after(hhh_lit)

order boy_school away extended extend_share, after(girl_school)

duplicates drop

compress

keep ///
hhid hhh_fem poly poly_hhh_fem poly_hhh_mal hhh_age hhh_edu hhh_prim hhh_noeduc ///
hhh_lit mem_n equiv_n adult_n workage_n child_n earlychild_n olderchild_n elder_n ///
depend child_school girl_school boy_school away extended extend_share ///
chef_pos

duplicates drop
sort hhid, stable

save "${baseline_intermediate}/demographics", replace
