
use "$baseline_intermediate/niger_main_2021.dta", clear
drop if consent == 0
drop consent


merge 1:1 hhid using "${baseline_intermediate}/identification.dta", ///
gen(_mtreat) keepusing(treatment)

global id_var hhid
global id_vars hhid


// keep downstream vars by section

local c22_vars  ce3_new accesstofunds ask_siblings ask_otherfam ask_friends ask_otherknown

local c23b_vars aff_ieff for_trust_1 enemy tens_comm

local c24_vars  partic soc_post aut_fond aut_volu worktogether_new


local downstream_sections  `c22_vars' `c23b_vars' `c24_vars'


foreach var in `downstream_sections' {
capture confirm var `var'
if _rc != 0 { // if var DNE, remove it from list to keep
local omit `var'
local downstream_sections : list downstream_sections - omit
}
}

else local keepextra

order $id_vars treatment `downstream_sections' `keepextra'
keep  $id_vars treatment `downstream_sections' `keepextra'


********************************************************************************
**** Downstream C.2.2 financial support index

/*
Can count on village community to help you financially [1-4]
Count of people could ask for money
Probability of putting together a small sum of money (0-4)  */

// ce3
recode ce3_new (5=1)(6=2)(7=3)(8=4)

// reverse access to funds since it's apparently decreasing
gen accesstofunds_rvrs = accesstofunds // as accesstofunds is negatively increasing
recode accesstofunds_rvrs (1 = 4) (2 = 3) (3 = 2) (4 = 1)

// ask vars
local ask_comp ask_siblings ask_otherfam ask_friends ask_otherknown
label var ask_siblings "No. of siblings that you can ask for money"
label var ask_otherfam "No. of family members that you can ask for money"
label var ask_friends "No. of friends that you can ask for money"
label var ask_otherknown"No. of other people that you can ask for money"

// two winsorization approaches:
// 1. winsorize number of siblings, sum it all up, and winsorize the total number
// 2. sum every thing up and then winsorize the result

// approach 1
gen ask_siblings_w = ask_siblings
_pctile ask_siblings, p(98)
replace ask_siblings_w  = `r(r1)' if !missing(ask_siblings) & ask_siblings > `r(r1)'

egen ask_sum1 = rowtotal(ask_siblings_w ask_otherfam ask_friends ask_otherknown), m // treats missing as zero unless all missing

gen ask_sum1_w = ask_sum1
_pctile ask_sum1, p(98)
replace ask_sum1_w  = `r(r1)' if !missing(ask_sum1) & ask_sum1 > `r(r1)'
label var ask_sum1_w ""

// approach 2
egen ask_sum2 = rowtotal(ask_siblings ask_otherfam ask_friends ask_otherknown), m // treats missing as zero unless all missing

gen ask_sum2_w = ask_sum2
_pctile ask_sum2, p(98)
replace ask_sum2_w  = `r(r1)' if !missing(ask_sum2) & ask_sum2 > `r(r1)'
label var ask_sum2_w "winsorized row sum"

label var ask_sum2_w "Count you could ask for money (winsorized row sum after winsorizing siblings variable)"
label var ask_sum1_w "Count you could ask for money (winsorized row sum)"


label var ce3_new  "Can count on village people to help financially if you face difficulties"
label var accesstofunds_rvrs "Probability of raising funds"


// approach 1
local financial_support_vars ce3_new ask_sum1_w accesstofunds_rvrs

*zindex `financial_support_vars', gen(fin_supp_index_1) condition(treatment == 1)
*label var fin_supp_index_1 "C.2.2 Financial support index (Z-score), wins. siblings then sum"

// approach 2
local financial_support_vars_keep ce3_new `ask_comp' ask_sum2_w accesstofunds_rvrs
local financial_support_vars   ce3_new  ask_sum2_w accesstofunds_rvrs


*zindex `financial_support_vars', gen(fin_supp_index_2) condition(treatment == 1)
*label var fin_supp_index_2 "C.2.2 Financial support index (Z-score), wins. sum"


local keep_2_2_extra ask_sum1_w

*Reallow once index constuction sorted
*order fin_supp_index_2 fin_supp_index_1 `keep_2_2_extra' `financial_support_vars_keep', last


********************************************************************************
**** Downstream C.2.3 (NEW-B) Social cohesion and closeness to community

/*  - Can count on other women in village [1-4](from old C.2.3) aff_ieff
- Out of ten, how many others in village can trust [0-10](from old C.2.3) for_trust_1
- Number of personal enemies [0-3](from old C.2.3) enemy
- Community tensions in last 6 months [0-3](from old C.2.3) tens_comm
- inclusion of self in (closeness to) community [1-4](from old C.2.3) los2
- scs3_new
- scs5_new_rvrs
- tg1_new
- tg4_new2
*/



**** ----------------| Downstream C.2.3 (NEW-B) Social cohesion and closeness to community

// a few vars only exist at baseline
label var aff_ieff "You can count on the help of the women of your village when you have difficulties" // increasing. keep
label var for_trust_1"Out of 10 people in the village, how many are honest and trustworthy people?" // 1-10

recode aff_ieff (5=1)(6=2)(7=3)(8=4)

gen socialcohesion = 0 if inlist(tens_comm, 1, 2, 3)
replace socialcohesion = 1 if tens_comm == 0
label variable socialcohesion "\makecell{Social \\ cohesion}" // higher value is better

********************************************************************************
**** Downstream C.2.4 groups and collective action

// Count of groups or associations that member, last 2 months
// Count of positions of responsibility in any group, last 12 months
// Amount given for community projects, last 2 months
// Days volunteered for community activities, last 2 months
// Works with community to achieve common goals [1-4]



label var partic "Count of groups or associations that member, last 2 months"
label var soc_post "Count of positions of responsibility in any group, last 12 months"
label var aut_fond "(FCFA) How much money have you given to a fund for community projects in the past two months?"
label var aut_volu "How many days have you spent in community activities in the last two months?"
label var worktogether_new"Works with community to achieve common goals [1-4]"

recode worktogether_new (5=1)(6=2)(7=3)(8=4)


/*
** conversion to purchasing power parity
rename aut_fond aut_fond_xof // run through all variables with FCFA units
currency_work aut_fond_xof, task("convert_ppp_2016") // generates *_ppp
currency_work aut_fond_xof, task("deflate_2016")     // deflates original
rename *_xof_ppp *_ppp // retain ppp suffix only
*/

rename aut_fond aut_fond_xof // run through all variables with FCFA units
gen aut_fond_ppp = aut_fond_xof

foreach var of varlist aut_fond_ppp aut_fond_xof {
_pctile `var' , p(98)

gen `var'_w = `var'
replace `var'_w  = `r(r1)' if !missing(`var'_w ) & `var'_w  > `r(r1)'
}
label var aut_fond_xof_w "Community project donations past 2 months (FCFA, Wins. 98p)"
label var aut_fond_ppp_w "Community project donations past 2 months (2016 USD, Wins. 98p)"


local collective_action_vars partic soc_post aut_fond_ppp_w aut_volu worktogether_new
*zindex `collective_action_vars', gen(collective_action_index) condition(treatment == 0)
*label var collective_action_index "C.2.4 Groups and collective action index (Z-score)"

order `collective_action_vars' aut_fond_xof_w, last
*readd once index consturction sorted collective_action_index





********************************************************************************
**** done

// BL c_2_2 and c_2_3
// FU c_2_1 and c_2_2 and c_2_3 and c_2_4 and c_2_5


save "$baseline_intermediate/social_wellbeing", replace



