clear
use "${community_raw}/community_analysis_panel_final.dta"

/* Steps taken to construct seasonal price deflator for maize, millet and rice

1. Clean price variables (e.g. so that 21 is relabeled as 210)
2. Use the average between retail and wholesale prices
3. Calculate the median price for each food item within each commune
4. Calculate the price deflator for each commodity
5. Weight the price deflator using the baseline share of consumption and aggregate across the three commodities

NOTE use variable 'month' in calculations, not 'months' - this variable is encoded and causes confusion when merging the HH data

NOTE do not merge on the commune code; it is not consistent between this dataset and the HH datasets
*/

drop commune_code
drop months

drop codevillage village_txt
drop commune_txt
rename commune commune_name
// rename commune_code commune
// label values commune .

gen year = 2022 if round == "baseline"
replace year = 2022 if inlist(round, "HF1_cohorte1", "HF1_cohorte2", "HF1_cohorte3", "HF1_cohorte4")
replace year = 2022 if inlist(round, "Midline_cohorte1", "Midline_cohorte2", "Midline_cohorte3")
replace year = 2022 if inlist(round, "HF2_cohorte1", "HF2_cohorte2", "HF2_cohorte3", "HF2_cohorte4")
replace year = 2023 if year == 2022 & month == "January"
replace year = 2023 if inlist(round, "endline")
replace month = "June" if month == "June23"

gen monthnum = month(date(month, "M"))
drop month
rename monthnum month

keep commune_name round year month prixkg_1_clean prixkg_2_clean prixkg_4_clean prixkg_5_clean
order commune_name round year month prixkg_1_clean prixkg_2_clean prixkg_4_clean prixkg_5_clean

duplicates drop
sort commune_name year month, stable

tempfile community
save "`community'"

* Calculate median prices for each commodity by commune and month

* Maize
clear
use "`community'"
collapse (median) maize_median=prixkg_1_clean, by(commune_name round year month)
tempfile median_maize_prices
save `median_maize_prices'

* Millet
clear
use "`community'"
collapse (median) millet_median=prixkg_2_clean, by(commune_name round year month)
tempfile median_millet_prices
save `median_millet_prices'

* Rice
clear
use "`community'"
collapse (median) rice_median=prixkg_4_clean, by(commune_name round year month)
tempfile median_rice_prices
save `median_rice_prices'

* niebe
clear
use "`community'"
collapse (median) niebe_median=prixkg_5_clean, by(commune_name round year month)
tempfile median_niebe_prices
save `median_niebe_prices'

clear
use `median_maize_prices'
merge 1:1 commune_name year month using `median_millet_prices'
drop _merge
merge 1:1 commune_name year month using `median_rice_prices'
drop _merge
merge 1:1 commune_name year month using `median_niebe_prices'
drop _merge

sort commune_name year month, stable

foreach commodity in maize millet rice niebe {
* Create the base price variable for February
by commune_name: egen base_`commodity'_price = mean(cond(month == 2 & round == "baseline", `commodity'_median, .))
    
* Generate the deflator for each commodity
gen `commodity'_deflator = `commodity'_median / base_`commodity'_price

drop base_`commodity'_price
}

merge m:1 commune_name using "${baseline_final}/staples-shares.dta"
drop _merge

gen deflator = maize_deflator*maize_share + millet_deflator*millet_share + rice_deflator*rice_share
label variable deflator "commune-month deflator, across three main staples"

replace commune_name = strupper(commune_name)

drop round
save "${community_final}/median_prices_all_commodities.dta", replace
