****************************************************************************
* -------------- I. drop duplicates and merge hhid ---------------- *
****************************************************************************

* duplicate drop list 
clear
import excel "${endline_raw_admin}/hfc_duplicates_endline.xlsx", firstrow
keep key drop hhid
rename key instance
tempfile hfc_drop_key_list
save "`hfc_drop_key_list'"

* get hhid from main dataset
clear
use "${endline_raw}/niger 2023- shock response- endline.dta"
destring hhid, replace
drop if missing(hhid)
rename key instance
merge m:1 hhid instance using "`hfc_drop_key_list'"
drop if drop == "drop"

gen surveyed_twice = 1 if _merge == 3
replace surveyed_twice = 0 if missing(surveyed_twice)

keep hhid instance surveyed_twice
tempfile hhid_key_v19
save "`hhid_key_v19'", replace

local dta_files : dir "${endline_raw}" files "*.dta"

foreach dta_file in `dta_files' {
    display as error "`dta_file'"
    use "${endline_raw}/`dta_file'", clear
    
    * drop duplicates in each file 
    
    cap sum parent_key
    
    if _rc == 0 {
        di "this is a long form dataset, with parent key and key"
        
        * first 41 characters are the instance/survey id
        gen instance = substr(parent_key, 1, 41)
        drop parent_key
        drop key
        * drop duplicates
        merge m:1 instance using "`hhid_key_v19'"
        keep if _merge == 3
        drop _merge
        drop instance
        drop surveyed_twice
        order hhid, first

    }
    
    else {
        * drop duplicates
        di "this is a wide form dataset"
        rename key instance
        merge m:1 hhid instance using "`hhid_key_v19'"
        keep if _merge == 3
        drop _merge
        
        order hhid, first
        
        drop oldlist*
        drop pull_*
        drop age_mem*
        drop resp_santeeduc_*
        drop employment_hh_mems_*
        drop calc_strategy*u
        
    }
    
    * shorten variable labels for Stata 13
    foreach i of varlist _all {
      local longlabel: variable label `i'
      local shortlabel = substr(`"`longlabel'"', 1, 79)
      label variable `i' `"`shortlabel'"'
    }

    if "`dta_file'" == "rpt_activitylist.dta" {
        * household by member by business activity level
        sort hhid agrd_key_rpos act_pos, stable
        drop if missing(bus2_active)
        order hhid agrd_key_rpos act_pos
        keep hhid agrd_key_rpos act_pos bus2_assval bus2_rev30 bus2_pro30 actdays_mem*
        duplicates drop
    }
   
    quietly ds *, not(type string)
    local nostrings = r(varlist)

    quietly {
    * recode numeric to missing
    mvdecode `nostrings', mv(-999 = .r) // refused
    mvdecode `nostrings', mv(-888 = .d) // don't know
    mvdecode `nostrings', mv(-777 = .o) // other
    mvdecode `nostrings', mv(-666 = .n) // na 
    mvdecode `nostrings', mv(-555 = .g) // god or unknown relation
    mvdecode `nostrings', mv(-333 = .m) 
    mvdecode `nostrings', mv(-222 = .r)
    mvdecode `nostrings', mv(-111 = .i)
    mvdecode `nostrings', mv(-99 = .i)
    mvdecode `nostrings', mv(-88 = .i)
    mvdecode `nostrings', mv(-77 = .i)
    mvdecode `nostrings', mv(-66 = .i)
    }
    
    save "${endline_intermediate}/`dta_file'", replace
    }

****************************************************************************
* -------------- II. Intial cleaning for all files ---------------- *
****************************************************************************

* randomization list
clear
use "${dataWorkFolder}/treatment_assignment/treatment_assignment.dta"

gen early_long = 0
replace early_long = 1 if treatment == 0

gen early_short = 0 
replace early_short = 1 if treatment == 1

gen late_short = 0
replace late_short = 1 if treatment == 2

drop treatment_definition

keep codevillage strat_vill_size strat_pmt treatment early_long early_short late_short
rename codevillage village

* note control group
label values treatment .
recode treatment (0 = 2) (2 = 0) (1 = 1)
label define treatment 0 "Traditional response" 1 "Early short" 2 "Early long", replace
label values treatment treatment

tempfile arms
save "`arms'"

* start with main dataset
clear
use "${endline_intermediate}/niger 2023- shock response- endline.dta", clear

drop if missing(hhid)
replace consent = 0 if missing(consent)
drop country_name country
drop currency survey_firm poly
drop hhid_enter hh_to_repeat_enter

* merge in treatment status
merge m:1 village using "`arms'"
drop _merge

sort commune_name village_name, stable
egen vid = group(commune_name village_name)

save "${endline_intermediate}/main_temp.dta", replace

clear
use "${endline_intermediate}/main_temp.dta"

gen dd = dofc(submissiondate)
format dd %td
gen month = month(dd)
gen year = year(dd)
order hhid commune commune_name submissiondate dd year month consent
drop dd

* assume these observations faced the prices in june
replace month = 6 if month == 7

merge m:1 commune_name year month ///
using "${community_final}/median_prices_all_commodities.dta"

drop if _merge == 2
drop _merge
drop maize_deflator millet_deflator rice_deflator niebe_deflator maize_share millet_share rice_share

tempfile main_build_temp
save "`main_build_temp'", replace

* start cleaning in the order of the survey

* module 1 intro
* module 2 consent
* module 3 household roster long format

* module 4 health and education

local hvars ///
health_a_has health_a_amt health_b_has health_b_amt health_c_has health_c_amt ///
health_d_has health_d_amt health_e_has health_e_amt health_f_has health_f_amt ///
health_g_has health_g_amt

label variable institution1 "If your family is sick, can you access hospital?"
label variable institution2 "If there is conflict, can you trust that police will intervene?"
label variable health_a_has "Cnsultling doctor costs?"
label variable health_b_has "Medical exam costs?"
label variable health_c_has "Out of hospital care costs?"
label variable health_d_has "Hospitalization costs?"
label variable health_e_has "Medicine costs?"
label variable health_f_has "Vaccination costs/"
label variable health_g_has "Pregnancy or related costs?"

local hvars health_a_amt health_b_amt health_c_amt health_d_amt health_e_amt health_f_amt health_g_amt
sum `hvars'

foreach var in `hvars' {
    _pctile `var', p(98)
    di r(r1)
    replace `var' = r(r1) if `var' > r(r1) & !missing(`var')
    replace `var' = 0 if missing(`var')
    label variable `var' "Amount"
}
sum `hvars'

local evars ///
edu_fee1 edu_fee2 edu_fee3 edu_fee4 edu_fee5 edu_fee6

label variable edu_fee1 "Total tuition"
label variable edu_fee2 "Total supply costs"
label variable edu_fee3 "Accommodation costs"
label variable edu_fee4 "Catering costs"
label variable edu_fee5 "Transport costs"
label variable edu_fee6 "Scholarships"

foreach var in `evars' {
    _pctile `var', p(98)
    di r(r1)
    replace `var' = r(r1) if `var' > r(r1) & !missing(`var')
    replace `var' = 0 if missing(`var')
    label variable `var' "Amount"
}

save "`main_build_temp'", replace

* note did not find missed school and could not pay school fees
* karim: these questions were not asked during endline because schools were closed

* module 5 income generating activities long format

clear
use "${endline_intermediate}/agr_na-emploi-rpt_wrk.dta"

* employment outside agriculture

label variable wrk_ag30 "Worked in agriculture in past 30 days?"
label variable wrk_ag12 "Worked in agriculture in past 12 months?"
label variable wrk_liv30 "Worked in livestock in past 30 days?"
label variable wrk_liv12 "Worked in livestock in past 12 months?"
label variable wrk_sal30 "Worked in salaried job in past 30 days?"
label variable wrk_sal12 "Worked in salaried job in past 12 months?"
label variable wrk_sal_n "How many salaried jobs in past 12 months?"
label variable wrk_na30 "Worked in non-agri business in past 30 days?"
label variable wrk_na12 "Worked in non-agri business in past 12 months?"

order hhid wrk_key_pos
sort hhid wrk_key_pos, stable

by hhid: egen nbusworkers = total(wrk_na30)
by hhid: egen nagworkers = total(wrk_ag30)
by hhid: egen nlivworkers = total(wrk_liv30)

keep hhid nbusworkers nagworkers nlivworkers
duplicates drop
gen business = 1 if nbusworkers > 0
replace business = 0 if missing(business)

gen agriculture = 1 if nagworkers > 0
replace agriculture = 0 if missing(agriculture)

gen livestock = 1 if nlivworkers > 0
replace livestock = 0 if missing(livestock)

label variable business "\makecell{Business \\ past month?}"
label variable agriculture "\makecell{Agriculture \\ past month?}"
label variable livestock "\makecell{Livestock \\ past month?}"

label variable nbusworkers "\makecell{\# of people \\ who worked in business}"

tempfile business
save "`business'"

clear

use "`main_build_temp'"
merge 1:1 hhid using "`business'"
drop _merge

save "`main_build_temp'", replace

clear
use "${endline_intermediate}/agr_na-emploi-rpt_empl.dta"

order hhid empl_key_pos
sort hhid empl_key_pos, stable

* to do *

clear
use "${endline_intermediate}/agr_na-na-rpt_agr_enum.dta"

sort hhid agr_key_pos agr_key_rpos, stable
order hhid agr_key_pos agr_key_rpos

ds *, not(type string)
local nostrings = r(varlist)

local nonfarm bus1_food bus1_tail bus1_constr bus1_comm bus1_prof bus1_serv bus1_trans bus1_art bus1_extra
sum `nonfarm'

foreach var in `nonfarm' {
    by hhid: egen `var'_temp = max(`var')
    drop `var'
}
local nonfarm bus1_food_temp bus1_tail_temp bus1_constr_temp bus1_comm_temp bus1_prof_temp bus1_serv_temp bus1_trans_temp bus1_art_temp bus1_extra_temp
egen nbusiness = rowtotal(`nonfarm')
label variable nbusiness "\makecell{\# of non-farm \\ businesses}"
keep hhid nbusiness
duplicates drop

tempfile nbusiness
save "`nbusiness'"

clear

use "`main_build_temp'"
merge 1:1 hhid using "`nbusiness'"
drop _merge

save "`main_build_temp'", replace

clear
use "${endline_intermediate}/rpt_activitylist.dta"

sort hhid act_pos agrd_key_rpos, stable
order hhid act_pos agrd_key_rpos

egen tt = rowtotal(actdays_mem*)
by hhid: egen n_days_business = total(tt)
drop actdays_mem*
drop tt

local bvars bus2_assval bus2_rev30 bus2_pro30

foreach var in `bvars' {
    _pctile `var', p(98)
    di r(r1)
    replace `var' = r(r1) if `var' > r(r1) & !missing(`var')
    replace `var' = 0 if missing(`var')
}

by hhid: egen bus_asset_value = total(bus2_assval)
by hhid: egen bus_revenue = total(bus2_rev30)
by hhid: egen bus_profit = total(bus2_pro30)

drop bus2_assval bus2_rev30 bus2_pro30
drop act_pos agrd_key_rpos

duplicates drop

label variable bus_asset_value "\makecell{Business \\ assets}"
label variable bus_profit "\makecell{Business \\ profits}"
label variable bus_revenue "\makecell{Business \\ revenue}"
label variable n_days_business "\# days business"

tempfile bprofits
save "`bprofits'"

clear

use "`main_build_temp'"
merge 1:1 hhid using "`bprofits'"
drop _merge

save "`main_build_temp'", replace

* to do *

clear
use "${endline_intermediate}/agr_na-emploi-d_hh_wage_labor.dta"
sort hhid d_hh_index, stable
order hhid d_hh_index

label variable d7_emp_days "\# days paid work in past thirty days, agri"
label variable d8_salary "Wages past thirty days, agri"
label variable d9_emp_days "\# days paid work in past thirty days, non-agri"
label variable d11_salary "Wages past thirty days, non-agri"

foreach var in d8_salary d11_salary {
    _pctile `var', p(98)
    replace `var' = r(r1) if `var' > r(r1) & !missing(`var')
    replace `var' = 0 if missing(`var')
}


by hhid: egen agri_emp = total(d7_emp_days)
by hhid: egen non_agri_emp = total(d9_emp_days)
by hhid: egen agri_wages = total(d8_salary)
by hhid: egen non_agri_wages = total(d11_salary)

keep hhid agri_emp non_agri_emp agri_wages non_agri_wages
duplicates drop

label variable agri_emp "\makecell{\# days in \\ agriculture wage}"
label variable non_agri_emp "\makecell{\# days in \\ other wage}"

label variable agri_wages "\makecell{Agri wage \\ income}"
label variable non_agri_wages "\makecell{Non-agri wage \\ income}"

tempfile wages
save "`wages'"

clear
use "`main_build_temp'"
merge 1:1 hhid using "`wages'"
drop _merge

replace agri_wages = 0 if missing(agri_wages)
replace non_agri_wages = 0 if missing(non_agri_wages)

replace agri_emp = 0 if missing(agri_emp)
replace non_agri_emp = 0 if missing(non_agri_emp)

gen agri_emp_binary = (agri_emp > 0)
label variable agri_emp_binary "\makecell{Agricultural \\ employment?}"

gen non_agri_emp_binary = (non_agri_emp > 0)
label variable non_agri_emp_binary "\makecell{Non-agricultural \\ employment?}"

save "`main_build_temp'", replace

* module 6 agriculture livestock wide and long format

* agriculture * three sections - crops, livestock, fishery

label variable hasplots "At least one HH member cultivated land in past 12 months?"
label variable plot_n "How many plots of land cultivated in past 12 months?"

label variable hasplots "\makecell{Farmed \\ past 12 months?}"
label variable plot_n "\# of plots farmed?"

drop plot_name*
drop rpt_plots_count resp_plot
drop resp_plot*

save "`main_build_temp'", replace

* plots gp_plots

clear
use "${endline_intermediate}/agriculture-plot-rpt_plots.dta"

sort hhid plot_pos, stable

* convert hectares to meter squared
replace plot_size = plot_size*10000 if plot_size_u == 1
replace plot_size_u = 2 if plot_size_u == 1
label variable plot_size "Plot size in metre squared"
label variable plot_man "Who manages the plot?"
label variable plot_owner "Who owns the plot?"

drop plot_ha
drop plot_key

split plot_man, parse(" ") gen(stub)
destring stub*, replace

egen all_members = anymatch(stub*), values(-1)
egen num_managers = rownonmiss(stub*) if all_members == 0
replace all_members = . if missing(plot_size)
replace num_managers = . if missing(plot_size)

label variable all_members "Whole HH manage plot (0/1)"
label variable num_managers "\# of HH managing this plot"

order hhid all_members num_managers

drop plot_man_*
drop stub*
drop plot_man

split plot_owner, parse(" ") gen(stub)
destring stub*, replace

egen external_owner = anymatch(stub*), values(0)
replace external_owner = . if missing(plot_size)
label variable external_owner "Plot (co)owned by someone outside of HH"
drop plot_owner_*
drop stub*
drop plot_owner

label variable plot_season "2022 rainy season, 2022-2023 dry season, or both"
label define plot_season 1 "rainy season only" 2 "dry season only" 3 "both seasons", replace

split plot_worked, parse(" ") gen(stub)
destring stub*, replace
egen num_workers = rownonmiss(stub*) if !missing(plot_worked)
order hhid stub* num_workers
drop plot_worked_*
drop stub*
drop plot_worked

label variable num_workers "\# of workers in plot x, rainy season"

egen tot_num_days = rowtotal(days_mem*), missing
drop days_mem*
label variable tot_num_days "\# of days worked on plot x, rainy season"
* this is # of days with atleast one hour worked on plot x, rainy season

drop plot_israin plotpos_israinandkey plot_isdry plotpos_isdryandkey
order hhid plot_pos plot_size
sort hhid plot_pos, stable

drop if missing(plot_size)
drop plot_size_u
drop plot_name

order hhid plot_pos plot_size all_members num_workers num_managers plot_season tot_num_days external_owner

sort hhid, stable
by hhid: gen nrainyplots = _N
label variable nrainyplots "\# of plots" // rainy season

foreach var in plot_size num_workers tot_num_days {
    winsor2 `var', replace cuts(0 98)
}

by hhid: egen avgplotsize = mean(plot_size)
by hhid: egen avgworkers = mean(num_workers)
by hhid: egen avgdaysworked = mean(tot_num_days)

by hhid: egen totalplotsize = total(plot_size)
label variable totalplotsize "\makecell{Total plot size}"

label variable avgplotsize "\makecell{Avg. plot \\ size}"
label variable avgworkers "\makecell{Avg. \# of \\ workers}"
label variable avgdaysworked "\makecell{Avg. \# of \\ days worked}"

local identifiers hhid plot_pos nrainyplots avgplotsize avgworkers avgdaysworked totalplotsize
ds `identifiers', not

foreach var in `r(varlist)' {
    ren `var' `var'_
    local l_`var'_ : variable label `var'_
}

levelsof plot_pos, local(plot_levels)

ds `identifiers', not
local stubnames "`r(varlist)'"
reshape wide `stubnames', i(hhid) j(plot_pos)

foreach variable of local stubnames {
foreach value of local plot_levels {
label variable `variable'`value' "`l_`variable'': plot # `value'"
}
}

order hhid nrainyplots avgplotsize avgworkers avgdaysworked totalplotsize

tempfile rpt_plots
save "`rpt_plots'"

clear
use "`main_build_temp'"
merge 1:1 hhid using "`rpt_plots'"
drop _merge

save "`main_build_temp'", replace

* rainy season crops gp_rainkeycond
* hh by plot

clear
use "${endline_intermediate}/gp_rainkeycond-rpt_rcrops.dta"
duplicates drop
drop if missing(rcrop_name)
destring rcrop_codeor_o, replace force
drop if missing(rcrop_codeor_o)
drop rcrop_codeor_o
sort hhid rcrop_name, stable

by hhid: gen plotid = _n
sort hhid plotid, stable
order hhid plotid
isid hhid plotid

label variable rcrop_name "Crop"
label variable rcrop_status "Finished harvesting crop?"
label variable rcrop_didsell "Sold (part of) harvest?"
label variable rainrcrop_harvn "\# of times crop has been planted" // on this plot during the rainy season

label define rcrop_status 1 "finished harvest" 2 "ongoing harvest" 3 "have not started" 0 "harvest lost", replace
label define rainrcrop_harvn 1 "Once" 2 "Twice", replace

drop harvestedrcrop soldrcrop
drop rcrop_controlrev rcrop_controlrev_*

sort hhid, stable
by hhid: egen soldharvest = max(rcrop_didsell) // sold harvest across all plots
label variable soldharvest "\makecell{Sold \\ harvest?}"

gen tempvar = 0 if inlist(rcrop_status, 0, 3)
replace tempvar = 1 if inlist(rcrop_status, 1, 2) // ongoing or finished harvest across all plots

by hhid: egen harvested = max(tempvar)
drop tempvar
label variable harvested "Harvested?"

by hhid: egen ncrops = max(plotid)
label variable ncrops "\# of crops planted?"

local identifiers hhid plotid soldharvest harvested ncrops
ds `identifiers', not

foreach var in `r(varlist)' {
    ren `var' `var'_
    local l_`var'_ : variable label `var'_
}

levelsof plotid, local(plotid)

ds `identifiers', not
local stubnames "`r(varlist)'"
reshape wide `stubnames', i(hhid) j(plotid)

foreach variable of local stubnames {
foreach value of local plotid {
label variable `variable'`value' "`l_`variable'': plot # `value'"
}
}

tempfile rainkeycond
save "`rainkeycond'"

clear
use "`main_build_temp'"

merge 1:1 hhid using "`rainkeycond'"
drop _merge

save "${endline_final}/main_build_temp.dta", replace

*** ag inputs and ag output ***

do "${do_endline_cleaning}/ag-inputs-outputs.do"

clear
use "${endline_final}/main_build_temp.dta"
merge 1:1 hhid using "${endline_final}/rcrops2.dta"
drop _merge

merge 1:1 hhid using "${endline_final}/dcrops2.dta"
drop _merge

merge 1:1 hhid using "${endline_final}/plots30.dta"
drop _merge

merge 1:1 hhid using "${endline_final}/cultivate.dta"
drop _merge

merge 1:1 hhid using "${endline_final}/drykeycond.dta"
drop _merge

replace harvested_dry = 0 if missing(harvested_dry)
replace soldharvest_dry = 0 if missing(soldharvest_dry)
replace n_days_cultivate = 0 if missing(n_days_cultivate)

* what inputs used for agriculture, ref period is last 30 days
* these are asked for a sub group only, not sure what is the filter - probably has yes plot_n30

tab mutual_labor mutual_support, m
tab inp_group mutual_support, m
tab mutual_support hasplots30, m

label variable hasplots30 "\makecell{Farming?}"
label variable plot_n30 "How many plots?"

label variable mutual_labor "\makecell{Mutual \\ labor?}"
label variable paid_labor30 "\makecell{Paid \\ labor?}"
label variable paid_labor_daily30 "Avg daily wages paid"
label variable paid_labor_total30 "\makecell{Wages \\ paid}"
label variable crop_didsell30 "\makecell{Sold \\ crops?}"
label variable crop_didsell_amt30 "\makecell{Sales \\ amount}"
label variable crop_seed30 "\makecell{Bought \\ seeds?}"
label variable crop_seed_purch30 "\makecell{Amount \\ spent}"
label variable crop_seed_kind30 "Type of seed"
label variable crop_fert30 "\makecell{Bought \\ fertlizers?}"
label variable crop_fert_purch30 "Amount spent"

tab crop_seed_kind30
recode crop_seed_kind30 (1 = 0) (2 = 1)
label define crop_seed_kind30 0 "Local" 1 "Improved", replace
label values crop_seed_kind30 crop_seed_kind30

sum mutual_labor paid_labor30 paid_labor_daily30 paid_labor_total30 crop_didsell30 crop_didsell_amt30 crop_seed30 crop_seed_purch30 crop_seed_kind30 crop_fert30 crop_fert_purch30

foreach var in crop_seed_purch30 crop_fert_purch30 {
    winsor2 `var', cuts(0 98) replace
}

foreach var in paid_labor_daily30 paid_labor_total30 crop_didsell_amt30 crop_seed_purch30 crop_seed_kind30 crop_fert_purch30 {
    replace `var' = 0 if hasplots30 == 1 & missing(`var')
}

sum mutual_labor paid_labor30 paid_labor_daily30 paid_labor_total30 crop_didsell30 crop_didsell_amt30 crop_seed30 crop_seed_purch30 crop_seed_kind30 crop_fert30 crop_fert_purch30

replace revenueharvest_dry = 0 if missing(revenueharvest_dry)

save "${endline_final}/main_build_temp.dta", replace

* rainy crops inputs across all plots

use "${endline_final}/main_build_temp.dta"

* what inputs used for agriculture, ref period is 2022 rainy season
* these apply to subset who said yes to hasplots

label variable inp_comp "\makecell{Household \\ compost?}"
label variable inp_fert "\makecell{Chemical \\ fertilizer?}"
label variable fert_purch "\makecell{Spend on \\ chem products}" // all plots
label variable inp_prod "\makecell{Phyto \\ products?}"
label variable prod_purch "\makecell{Spend on \\ phyto products}" // all plots
label variable inp_group "\makecell{Mutual support \\ labour?}"
label variable inp_paidlab "\makecell{Paid \\ labor?}"
label variable inp_paidlabamt "\makecell{Spend on \\ paid labor}" // all plots

foreach var in fert_purch prod_purch inp_paidlabamt {
    winsor2 `var', replace cuts(0 98)
}

replace fert_purch = 0 if missing(fert_purch) & !missing(inp_fert)
replace prod_purch = 0 if missing(prod_purch) & !missing(fert_purch)
replace inp_paidlabamt = 0 if missing(inp_paidlabamt) & !missing(inp_paidlab)

sum inp_comp inp_fert fert_purch inp_prod prod_purch inp_group inp_paidlab inp_paidlabamt hasplots30

* agriculture, livestock, and fishing in past month

save "${endline_final}/main_build_temp.dta", replace

* livestock

use "${endline_final}/main_build_temp.dta"

label variable own_livestock "During the last 30 days, <b> owned </b> animals or <b> raised </b> animals that do not belong to them?"
label variable has_livestock "During the last 12 months, <b>own</b> animals or <b>raise</b> animals that did not belong to them?"
label variable who_fourleg "Which HH members manage the livestock?"
replace who_fourleg = "" if who_fourleg == "-2"
split who_fourleg, parse(" ") gen(stub)
destring stub*, replace
egen num_liv_managers = rownonmiss(stub*)
order hhid stub* num_liv_managers
replace num_liv_managers = . if num_liv_managers == 0
label variable num_liv_managers "\# of HH managing livestock"
drop stub*
drop who_fourleg*

save "${endline_final}/main_build_temp.dta", replace

use "${endline_intermediate}/agriculture-livestock-gp_haslivestock-r_four.dta", clear
sort hhid liv_mm_pos, stable

by hhid: egen n_days_livestock = total(num_days_livestock)
keep hhid n_days_livestock
duplicates drop
label variable n_days_livestock "\makecell{\# days \\ livestock}"

tempfile aglive
save "`aglive'"

clear
use "${endline_final}/main_build_temp.dta"
merge 1:1 hhid using "`aglive'"
drop _merge

replace n_days_livestock = 0 if missing(n_days_livestock)

save "${endline_final}/main_build_temp.dta", replace


clear
use "${endline_intermediate}/agriculture-livestock-gp_haslivestock-rpt_ani1.dta"

sort hhid ani1_pos, stable
order hhid ani1_pos

replace ani1_name = strlower(ani1_name)

gen weight = 1.1 if ani1_name == "chamelon"
replace weight = 1.1 if ani1_name == "chameau / chamelle"
replace weight = 0.8 if ani1_name == "chevaux / juments"
replace weight = 0.8 if ani1_name == "anes / anesses"
replace weight = 0.7 if ani1_name == "vache / genisse"
replace weight = 0.7 if ani1_name == "veau / velle"
replace weight = 0.5 if ani1_name == "boeuf / taureau"
replace weight = 0.5 if ani1_name == "taurillon"
replace weight = 0.1 if ani1_name == "mouton / belier"
replace weight = 0.1 if ani1_name == "bouc / chevre"
replace weight = 0.1 if ani1_name == "brebis"
replace weight = 0.03 if ani1_name == "pintades"
replace weight = 0.01 if ani1_name == "poules / poulets locaux"

foreach var in ani_count {
    _pctile `var', p(98)
    replace `var' = r(r1) if `var' > r(r1) & !missing(`var')
    replace `var' = 0 if missing(`var')
}

gen xx = ani_count*weight

by hhid: egen livestock_tlu = total(xx)

by hhid: egen tvo = total(ani_value)
drop ani_value
rename tvo ani_value

by hhid: egen tvo = total(ani_prod_value30)
drop ani_prod_value30
rename tvo ani_prod_value30

keep hhid livestock_tlu ani_value ani_prod_value30
duplicates drop

label variable livestock_tlu "\makecell{\# of \\ livestock}"

tempfile livestock
save "`livestock'"

clear
use "${endline_final}/main_build_temp.dta"
merge 1:1 hhid using "`livestock'"
drop _merge

replace livestock_tlu = 0 if missing(livestock_tlu)

save "${endline_final}/main_build_temp.dta", replace


/*

boeuf / taureau
vache / genisse
veau / velle
mouton / belier
brebis
bouc / chevre
chameau / chamelle
anes / anesses
chevaux / juments
poules / poulets locaux
pintades
chamelon
taurillon


ox / bull
cow/heifer
calf / calf
sheep / ram
sheep
goat / goat
camel / camel
donkeys / donkeys
horses/mares
local hens/chickens
guinea fowl
camel
bull


• Camels = 1.1
• Horses, mares, or donkeys = 0.8
• Cows and calves = 0.70
• Bulls = 0.5
• Pigs = 0.20
• Sheep, goats, and mutton = 0.10
• Guinea Fowl = 0.03
• Chicken = 0.01

gen livestock_tlu=.
label variable livestock_tlu "livestock count TLU"
replace livestock_tlu=0 if own_livestock==0 
replace livestock_tlu = 0.01*temp_hh_chicken + 0.1*temp_hh_goat + 0.7*temp_hh_cow + 0.1*temp_hh_sheep + temp_hh_loth
replace livestock_tlu=. if missing(hh_chicken) & missing(hh_goat) & missing(hh_cow) & missing(hh_sheep) & missing(hh_loth) 

*/




* fish




* module 7 food security
clear
use "${endline_final}/main_build_temp.dta"

* food insecurity scale (past twelve months)
label variable food1 "Worried about food?"
label variable food2 "Unable to eat healthy due to lack of money?"
label variable food3 "Ate less varied food due to lack of money?"
label variable food4 "Skipped meal due to lack of money?"
label variable food5 "Ate less than you wanted due to lack of money?"
label variable food6 "Ran out of food due to lack of money?"
label variable food7 "Hungry but could not eat due to lack of money?"
label variable food7b "How often were you hungry?"
label variable food8 "\makecell{Whole day \\ without food?}"
label variable food8b "How often did you go a whole day with no food?"
label variable food8c "\makecell{\# days \\ without food}"
label variable food10 "When you lack food, in what order does HH eat?"
* to do: food_men food_women food_boys food_girls
label variable food11 "Probability of going whole day without food next year?"

foreach var in food8c {
    _pctile `var', p(98)
    replace `var' = r(r1) if `var' > r(r1) & !missing(`var')
}

replace food8c = 0 if food8 == 0

label variable food8b "How often did you go a whole day with no food?"
label define food8b 1 "only once or twice or never" 2 "a few months but not every month" 3 "almost every month", replace
label values food8b food8b

replace food8b = 1 if food8 == 0

gen food8b_rev = -food8b
label variable food8b_rev "\makecell{How often \\ days with food}"

local fies food1 food2 food3 food4 food5 food6 food7 food8
egen fies = rowtotal(`fies')
replace fies = -fies
label variable fies "\makecell{Food \\ security}"

gen food8c_rev = -food8c
label variable food8c_rev "\makecell{Days with \\ food}"

gen food8_rev = 1 if food8 == 0
replace food8_rev = 0 if food8 == 1
label variable food8_rev "\makecell{Not hungry \\ all day?}"

* food consumption score (past week)
* in the past seven days, how many days did the HH eat:
label variable div_cereal "Cereals"
label variable div_pulse "Legumes, nuts"
label variable div_milk "Milk, dairy"
label variable div_meat "Meat, fish, eggs"
label variable div_meat2 "Meat flesh"
label variable div_meat_org "Meat organ"
label variable div_fish "Fish and molluscs"
label variable div_egg "Eggs"
label variable div_veg "Vegetables"
label variable div_veg_vita "Orange vegetables"
label variable div_vega "Green vegetables"
label variable div_fruit "Fruits"
label variable div_fruit_vita "Fruits orange"
label variable div_oil "Oil, fats, butter"
label variable div_sugar "Sugar, sweets"
label variable div_spice "Condiments and spices"

* Infant Minimum Dietary Diversity (MDD) (past 24 hours)

label variable div_milk_mat_child "Breast milk"
label variable div_cereal_child "Cereals"
label variable div_pulse_child "Legumes"
label variable div_milk_child "Milk, dairy"
label variable div_meat_child "Meat and fish"
label variable div_egg_child "Eggs"
label variable div_fruit_vita_child "Fruits and vegetables greens"
label variable div_fruit_child "Other fruits and vegetables"

* Mother of Infant Minimum Dietary Diversity (MDD) (past 24 hours)

label variable div_cereal_mom "Cereals"
label variable div_pulse_mom "Peas, beans"
label variable div_pulse2_mom "Peanuts, sesame, seeds"
label variable div_milk_mom "Milk, dairy"
label variable div_meat_mom "Meat"
label variable div_egg_mom "Eggs"
label variable div_veg_mom "Vegetables greens"
label variable div_fruit1_mom "Mango and papaya"
label variable div_veg_vita_mom "Other vegetables"
label variable div_fruit_mom "Banana, apple, lemon"

* Children Minimum Dietary Diversity (MDD) (past 24 hours)

label variable div_cereal_child2 "Cereals"
label variable div_pulse_child2 "Peas, beans"
label variable div_pulse2_child2 "Peanuts, sesame, seeds"
label variable div_milk_child2 "Milk, dairy"
label variable div_meat_child2 "Meat"
label variable div_egg_child2 "Eggs"
label variable div_veg_child2 "Vegetables greens"
label variable div_fruit1_child2 "Mango and papaya"
label variable div_veg_vita_child2 "Other vegetables"
label variable div_fruit_child2 "Banana, apple, lemon"

egen meatx = rowmax(div_meat div_meat2 div_meat_org div_fish div_egg)
egen vegx = rowmax(div_veg div_veg_vita div_vega)
egen fruitx = rowmax(div_fruit div_fruit_vita)

* note cereals includes tubers so the modified definition is below, taken from midline
* fcs = 2*cereals + 3*pulses + 1*vegetables + 1*fruit + 4*meat/fish/eggs + 4*milk + 0.5*oil + 0.5*sugar
* fcs = 2*div_cereal + 3*div_pulse + 1*div_veg + 1*div_fruit + 4*div_meat + 4*div_milk + 0.5*div_oil + 0.5*div_sugar

drop div_meat div_meat2 div_meat_org div_fish div_egg
drop div_veg div_veg_vita div_vega
drop div_fruit div_fruit_vita

rename meatx div_meat
rename vegx div_veg
rename fruitx div_fruit

label variable div_veg "Vegetables"
label variable div_fruit "Fruits"
label variable div_meat "Meat, fish, eggs"

gen fcs = 2*div_cereal + 3*div_pulse + 1*div_veg + 1*div_fruit + 4*div_meat + 4*div_milk + 0.5*div_oil + 0.5*div_sugar

label variable fcs "FCS"

gen fcs_above_poor = (fcs > 21)
replace fcs_above_poor = . if missing(fcs)
label variable fcs_above_poor "FCS above poor"

gen fcs_above_reason = (fcs > 42)
replace fcs_above_reason = . if missing(fcs)
label variable fcs_above_reason "FCS above reasonable"

// div_cereal div_pulse div_milk div_meat div_meat2 div_meat_org div_fish div_egg div_veg div_veg_vita div_vega div_fruit div_fruit_vita div_oil div_sugar div_spice

egen mdd_i_score = rowtotal(div_milk_mat_child div_cereal_child div_pulse_child div_milk_child div_meat_child div_egg_child div_fruit_vita_child div_fruit_child), missing 
label var mdd_i_score "\makecell{MDD \\ Infant}"

egen pulsex = rowmax(div_pulse_child)
egen meatx = rowmax(div_meat_child div_egg_child)
egen fruitx = rowmax(div_fruit_vita_child div_fruit_child)

drop div_pulse_child
drop div_meat_child div_egg_child
drop div_fruit_vita_child div_fruit_child

rename pulsex div_pulse_child
rename meatx div_meat_child
rename fruitx div_fruit_child

gen fcs_infant = 2*div_cereal_child + 3*div_pulse_child + 1*div_fruit_child + 4*div_meat_child + 4*div_milk_mat_child
replace fcs_infant = fcs_infant*7

label variable fcs_infant "FCS (infant)"

egen mdd_w_score = rowtotal(div_cereal_mom div_pulse_mom div_pulse2_mom div_milk_mom div_meat_mom div_egg_mom div_veg_mom div_fruit1_mom div_veg_vita_mom div_fruit_mom), missing 
label var mdd_w_score "\makecell{MDD \\ Mother}"
* this is mother of infant

egen pulsex = rowmax(div_pulse_mom div_pulse2_mom)
egen meatx = rowmax(div_meat_mom div_egg_mom)
egen vegx = rowmax(div_veg_mom div_veg_vita_mom)
egen fruitx = rowmax(div_fruit1_mom div_fruit_mom)

drop div_pulse_mom div_pulse2_mom
drop div_meat_mom div_egg_mom
drop div_veg_mom div_veg_vita_mom
drop div_fruit1_mom div_fruit_mom

rename pulsex div_pulse_mom
rename meatx div_meat_mom
rename vegx div_veg_mom
rename fruitx div_fruit_mom

gen fcs_mother = 2*div_cereal_mom + 3*div_pulse_mom + 1*div_veg_mom + 1*div_fruit_mom + 4*div_meat_mom + 4*div_milk_child2
replace fcs_mother = fcs_mother*7
label variable fcs_mother "FCS (mother)"

egen mdd_c_score = rowtotal(div_cereal_child2 div_pulse_child2 div_pulse2_child2 div_milk_child2 div_meat_child2 div_egg_child2 div_veg_vita_child2 div_fruit1_child2 div_veg_vita_child2 div_fruit_child2), missing 
label var mdd_c_score "\makecell{MDD \\ Child}"

egen pulsex = rowmax(div_pulse_child2 div_pulse2_child2)
egen meatx = rowmax(div_meat_child2 div_egg_child2)
egen vegx = rowmax(div_veg_vita_child2)
egen fruitx = rowmax(div_fruit1_child2 div_fruit_child2)

gen fcs_child = 2*div_cereal_child2 + 3*pulsex + 1*vegx + 1*fruitx + 4*meatx + 4*div_milk_child2
replace fcs_child = fcs_child*7

label variable fcs_child "FCS (child)"

gen mdd_c_binary = 1 if mdd_c_score >= 4 & !missing(mdd_c_score)
replace mdd_c_binary = 0 if mdd_c_score < 4
label var mdd_c_binary "MDD Child (0/1)"

save "${endline_final}/main_build_temp.dta", replace

do "${do_endline_cleaning}/endline-food.do"

clear
use "${endline_final}/main_build_temp.dta"
merge 1:1 hhid using "${endline_final}/hh_food_consumption.dta"
drop _merge

label variable eat_out "In past week, has anyone in HH eaten out?"
label variable eat_out_xof "Spending"
drop eat_out_who_*

label variable eat_out_who "Who ate out?"
label variable eat_share "In past week, any meals shared with non-HH?"
label variable eat_kids_days "In past week, how many days meal shared with non-HH kids>"
label variable eat_kids_meals "In past week, how many meals shared with non-HH kids?"

label variable eat_adults_days "In past week, how many days meal shared with non-HH adults>"
label variable eat_adults_meals "In past week, how many meals shared with non-HH adults?"

// sum consum_market xtemp consum_qty consum_prod consum_gift

save "${endline_final}/main_build_temp.dta", replace

* module 9 exceptional expense long format

* food, drink, and other expenses

* in the past six months

clear
use "${endline_intermediate}/nfconsumption-gp_cel-rpt_cel1.dta"
order hhid cel1_pos
sort hhid cel1_pos, stable

clear
use "${endline_intermediate}/nfconsumption-gp_cel-rpt_cel2.dta"
order hhid cel2_pos
sort hhid cel2_pos, stable

local fiesta cel_food cel_drink cel_cloth cel_nonfood

egen exp = rowtotal(`fiesta')
by hhid: egen xx = total(exp)

keep hhid xx
duplicates drop

rename xx cel_expenses
label variable cel_expenses "Food and other expenses, past six months"

tempfile cel_expenses
save "`cel_expenses'"

clear

* non-food expenses

* in the lean period

clear
use "${endline_intermediate}/nfconsumption-gp_nonfood-rpt_nonfood.dta"

order hhid nonfood_pos nonfood_period
sort hhid nonfood_pos nonfood_period, stable

sort hhid nonfood_period, stable

by hhid nonfood_period: egen xx = total(consum_nf_val)
keep hhid nonfood_period xx
duplicates drop

gen refperiod = 1 if nonfood_period == "7 derniers jours"
replace refperiod = 2 if nonfood_period == "30 derniers jours"
replace refperiod = 3 if nonfood_period == "6 derniers mois"
replace refperiod = 4 if nonfood_period == "12 derniers mois"

drop nonfood_period

rename xx nf_expenses_
reshape wide nf_expenses_, i(hhid) j(refperiod)

tempfile nf_expenses
save "`nf_expenses'"

clear
use "${endline_final}/main_build_temp.dta"
merge 1:1 hhid using "`cel_expenses'"
drop _merge

drop resp_nonfood_*

merge 1:1 hhid using "`nf_expenses'"
drop _merge

/*

health_a_amt health_b_amt health_c_amt health_d_amt health_e_amt health_f_amt health_g_amt // asked for past six months
edu_fee1 edu_fee2 edu_fee3 edu_fee4 edu_fee5 edu_fee6 // for school year
cel_expenses // past six months
nf_expenses_3 // past six months

*/

foreach var in edu_fee1 edu_fee2 edu_fee3 edu_fee4 edu_fee5 edu_fee6 {
    replace `var' = `var'/2 
}


local ex_expenses ///
health_a_amt health_b_amt health_c_amt health_d_amt health_e_amt health_f_amt health_g_amt ///
edu_fee1 edu_fee2 edu_fee3 edu_fee4 edu_fee5 edu_fee6 ///
cel_expenses ///
nf_expenses_3

foreach var in `ex_expenses' {
    _pctile `var', p(98)
    di r(r1)
    replace `var' = r(r1) if `var' > r(r1) & !missing(`var')
    replace `var' = 0 if missing(`var')
}

local ex_expenses ///
health_a_amt health_b_amt health_c_amt health_d_amt health_e_amt health_f_amt health_g_amt ///
edu_fee1 edu_fee2 edu_fee3 edu_fee4 edu_fee5 edu_fee6 ///
cel_expenses ///
nf_expenses_3

egen ex_expenses = rowtotal(`ex_expenses')
replace ex_expenses = ex_expenses/6 // convert from six months to monthly
label variable ex_expenses "\makecell{Non-food \\ consumption}"


gen total_consumption = ex_expenses + proxycon_mt
label variable total_consumption "\makecell{Total HH \\ consumption}"

gen off_farm = 1 if important_activity == 3 | important_activity == 4
replace off_farm = 0 if important_activity == 1 | important_activity == 2 | important_activity == 0
label variable off_farm "\makecell{Main activity \\ off-farm?}"

save "${endline_final}/main_build_temp.dta", replace

* module 10 assets long format

* agricultural assets

clear
use "${endline_intermediate}/assets-rpt_ag_ass.dta"

sort hhid ag_ass_pos, stable
winsor2 ass_ag_val, cuts(0 98) replace
by hhid: egen ag_asset_value = total(ass_ag_val), missing
label variable ag_asset_value "Value of ag. assets"

keep hhid ag_ass_pos ass_ag ag_asset_value
rename ass_ag ass_ag_

reshape wide ass_ag_, i(hhid) j(ag_ass_pos)

pca ass_ag_*, components(1)
predict xx

egen ag_ass_index = std(xx), mean(0) sd(1)
label variable ag_ass_index "Ag assets index"

keep hhid ag_ass_index ag_asset_value

tempfile ag_ass_index
save "`ag_ass_index'"

clear

use "${endline_final}/main_build_temp.dta"
merge 1:1 hhid using "`ag_ass_index'"
drop _merge

save "${endline_final}/main_build_temp.dta", replace

* household assets

clear
use "${endline_intermediate}/assets-rpt_hh_ass.dta"

sort hhid ass_hh_pos, stable
keep hhid ass_hh_pos ass_hh

rename ass_hh ass_hh_

reshape wide ass_hh_, i(hhid) j(ass_hh_pos)

pca ass_hh_*, components(1)
predict xx

egen hh_ass_index = std(xx), mean(0) sd(1)
label variable hh_ass_index "HH assets"

keep hhid hh_ass_index

tempfile hh_ass_index
save "`hh_ass_index'"

clear

use "${endline_final}/main_build_temp.dta"
merge 1:1 hhid using "`ag_ass_index'"
drop _merge
merge 1:1 hhid using "`hh_ass_index'"
drop _merge

drop resp_ass_*

save "${endline_final}/main_build_temp.dta", replace

* module 11 finance wide and long format

* savings

* past twelve months

label variable sav_loc "In past twelve months, have you saved in:"
label variable save_loc1 "Bank"
label variable save_loc2 "Savings group"
label variable save_loc3 "Cash with family outside HH"
label variable save_loc4 "Cash with neighbours, friends"
label variable save_loc5 "Merchant"
label variable save_loc6 "Cash at home"
label variable save_loc7 "Cash on you"
label variable save_loc8 "Cards, tickets"
label variable save_loc9 "Agri cooperative"
label variable save_loc10 "Mobile money"
label variable save_loc11 "Jewellery"

save "${endline_final}/main_build_temp.dta", replace

* past three months

clear
use "${endline_intermediate}/finance-part_othersave-gp_savemoreinfo.dta"

label variable dep_xof "Savings in past three months (amt)"
label variable sav_bal "Savings balance (amt)"
label variable with_xof "Withdrawn in past three months (amt)"

sort hhid saves_pos, stable

replace saves_pos = 3 if saves_pos == 4
replace saves_pos = 4 if saves_pos >= 5
drop saves_loc_name

sort hhid saves_pos, stable
order hhid sav_bal dep_xof dep_times

by hhid: egen saved_binary_ = total(dep_times), missing
replace saved_binary_ = 0 if missing(saved_binary_)
replace saved_binary_ = 1 if saved_binary_ > 0
by hhid saves_pos: egen saved_amt_ = total(dep_xof), missing
by hhid saves_pos: egen savings_bal_ = total(sav_bal), missing

keep hhid saves_pos saved_binary_ saved_amt_ savings_bal_
duplicates drop

reshape wide savings_bal_ saved_amt_, i(hhid) j(saves_pos)

label variable saved_amt_1 "\makecell{Savings, \\ bank}"
label variable saved_amt_2 "\makecell{Savings, \\ savings groups}"
label variable saved_amt_3 "\makecell{Savings, \\ family}"
label variable saved_amt_4 "\makecell{Savings, \\ others}"

label variable savings_bal_1 "Savings bal, bank"
label variable savings_bal_2 "Savings bal, savings groups"
label variable savings_bal_3 "Savings bal, family"
label variable savings_bal_4 "Savings bal, others"

label variable saved_binary_ "\makecell{Saved in past \\ three months}"

foreach var in saved_amt_1 saved_amt_2 saved_amt_3 saved_amt_4 {
    _pctile `var', p(98)
    di r(r1)
    replace `var' = r(r1) if `var' > r(r1) & !missing(`var')
    replace `var' = 0 if missing(`var')
}

foreach var in savings_bal_1 savings_bal_2 savings_bal_3 savings_bal_4 {
    _pctile `var', p(98)
    di r(r1)
    replace `var' = r(r1) if `var' > r(r1) & !missing(`var')
    replace `var' = 0 if missing(`var')
    * winsorize before filling in missings with zeroes, otherwise everything may be 
    * replaced by zeroes
}

egen saved_total = rowtotal(saved_amt_1 saved_amt_2 saved_amt_3 saved_amt_4), missing
label variable saved_total "\makecell{Total amount saved}"

egen sbalance = rowtotal(savings_bal_1 savings_bal_2 savings_bal_3 savings_bal_4), missing
label variable sbalance "Savings balance"

egen sbalance_inf = rowtotal(savings_bal_3 savings_bal_4), missing
label variable sbalance_inf "Savings balance, informal"

egen sbalance_for = rowtotal(savings_bal_1 savings_bal_2), missing
label variable sbalance_for "Savings balance, formal"

* dividing so that it is comparable to previous rounds
foreach var in saved_total sbalance sbalance_inf sbalance_for {
    replace `var' = `var' / 3
}

gen s_bank = 1 if saved_amt_1 > 0
replace s_bank = 0 if missing(s_bank)
label variable s_bank "Saved in bank in last 3 months" 

sum saved_amt* savings_bal*

tempfile savings
save "`savings'", replace

use "${endline_final}/main_build_temp.dta"
merge 1:1 hhid using "`savings'"
drop _merge

save "${endline_final}/main_build_temp.dta", replace

* credit

* past twelve months
clear
use "${endline_final}/main_build_temp.dta"

label variable cred "In past twelve months, have you taken a loan from:"

label variable cred_1 "Savings group"
label variable cred_2 "Friend or neighbour"
label variable cred_3 "Member of HH"
label variable cred_4 "Usurer"
label variable cred_4 "Moneylender, loan shark"
label variable cred_5 "Trader"
label variable cred_6 "Bank, NGO, microfinance"
label variable cred_7 "Other person, group"
label variable cred_no "In past twelve months, any loan request rejected?"

local sources cred_1 cred_2 cred_3 cred_4 cred_5 cred_6 cred_7
egen loans_twelve_mo = rowtotal(`sources')
replace loans_twelve_mo = 1 if loans_twelve_mo > 0
label variable loans_twelve_mo "\makecell{Borrowed (0, 1)}"

gen loans_formal = 1 if cred_1 == 1 | cred_6 == 1
replace loans_formal = 0 if missing(loans_formal)
label variable loans_formal "Took formal loan in past 12 months"

gen loans_informal = 1 if loans_twelve_mo == 1 & loans_formal == 0
replace loans_informal = 0 if missing(loans_informal)
label variable loans_informal "Took informal loan in past 12 months"

save "${endline_final}/main_build_temp.dta", replace

clear
use "${endline_intermediate}/finance-part_credit-rpt_cred.dta"

sort hhid cred_pos, stable

by hhid: egen loans_amt = total(cred_amt), missing
keep hhid loans_amt
label variable loans_amt "\makecell{Amount \\ borrowed}"

duplicates drop

foreach var in loans_amt {
    _pctile `var', p(98)
    replace `var' = r(r1) if `var' > r(r1) & !missing(`var')
    replace `var' = 0 if missing(`var')
}

sum loans_amt
* dividing so that it is comparable to previous rounds
replace loans_amt = loans_amt / 12

tempfile loans
save "`loans'"

use "${endline_final}/main_build_temp.dta"
merge 1:1 hhid using "`loans'"
drop _merge

foreach var in ask_siblings ask_otherfam ask_friends ask_otherknown {
     _pctile `var', p(98)
    replace `var' = r(r1) if `var' > r(r1) & !missing(`var')
    replace `var' = 0 if missing(`var')
}

egen fin_support = rowtotal(ask_mon ask_dad ask_siblings ask_otherfam ask_friends ask_otherknown)
label variable fin_support "\# of people can ask for financial support"

* access
label variable accesstofunds "Confident of raising 30000 FCFA"
label values accesstofunds .
recode accesstofunds (1 = 1) (2 = 1) (3 = 0) (4 = 0)
label define accesstofunds 0 "Very unlikely" 1 "Very likely", replace
label values accesstofunds accesstofunds

// egen risk_sharing = rowtotal(fin_support accesstofunds)
//
// sum risk_sharing if treatment == 0
// replace risk_sharing = risk_sharing - r(mean)
// replace risk_sharing = risk_sharing/r(sd)
// sum risk_sharing

gen risk_sharing = accesstofunds
label variable risk_sharing "\makecell{Risk-sharing \\ ability}"

save "${endline_final}/main_build_temp.dta", replace

* module 12 psychosocial well-being
clear
use "${endline_final}/main_build_temp.dta"

* future expectations index
label variable stair_satis_future "Life satisfaction in two years"
label variable stair_status_future "Status in two years"

egen futureexp = rowtotal(stair_satis_future stair_status_future), missing

sum futureexp if treatment == 0
replace futureexp = futureexp - r(mean)
replace futureexp = futureexp/r(sd)
sum futureexp
label variable futureexp "Expectations"

* social standing index
label variable stair_status_today "Status today"
label variable stair_good_today "Have good qualities today"
label variable stair_respect_new "Respect in society today"
label variable stair_opinion_new "Opinion has value today"

egen socstanding = rowtotal(stair_status_today stair_good_today stair_respect_new stair_opinion_new), missing

sum socstanding if treatment == 0
replace socstanding = socstanding - r(mean)
replace socstanding = socstanding/r(sd)
sum socstanding
label variable socstanding "\makecell{Social \\ standing}"

label variable stair_satis_today "Cantril"

* agree statements
label variable ce3_new "Can rely on village for financial help"
label variable worktogether_new "Work with community for common goals"
label variable aff_ieff "Can rely on village women for help" 

* mental health (in the past week)

label variable los1 "Close to your community"

label variable cd1 "More disturbed than usual"
label variable cd2 "Trouble focusing"
label variable cd3_new "Felt sad"
label variable cd4 "Taking more energy than usual"
label variable cd5 "Felt confident about future"
label variable cd6_new "Felt nervous or tense"
label variable cd7 "Had trouble sleeping"
label variable cd8 "Felt happy"
label variable cd9 "Felt alone"
label variable cd10_new "Too tired to do anything"
label variable useless "Felt unproductive"

replace cd5 = 7 - cd5
replace cd8 = 7 - cd8
egen mentalhealth = rowtotal(cd1 cd2 cd3_new cd4 cd5 cd6_new cd7 cd8 cd9 cd10_new useless), missing
/* Phyllisa march 19th 2025 we standardise other rounds using baseline values.
sum mentalhealth if treatment == 0
replace mentalhealth = mentalhealth - r(mean)
replace mentalhealth = mentalhealth/r(sd)

replace mentalhealth = -mentalhealth */ // higher values mean better health
label variable mentalhealth "\makecell{Mental \\ health}"



* social cohesion
label variable tens_comm "Tension within community?"
label variable tens "Tension between HH and community?"

gen socialcohesion = 0 if tens == 1
replace socialcohesion = 1 if tens == 0
label variable socialcohesion "\makecell{Social \\ cohesion}" // higher value is better

* groups and collective action
label variable partic "\# of memberships"
label variable soc_post "\# of responsibilities"
label variable aut_fond "Donations to community groups"
label variable aut_volu "Volunteer time to groups"

foreach var in aut_fond aut_volu {
    _pctile `var', p(2, 98)
    replace `var' = r(r1) if `var' < r(r1)
    replace `var' = r(r2) if `var' > r(r2) & !missing(`var')
}

egen collective = rowtotal(partic soc_post aut_fond aut_volu), missing

sum collective if treatment == 0
replace collective = collective - r(mean)
replace collective = collective/r(sd)
sum collective
label variable collective "\makecell{Collective \\ action}"

* violence perceptions
label variable ten_tension "How many women in ten experience tension in HH?"
label variable vill_burn "Common for husbands to beat wives?"

label define villburn 1 "no" 2 "could happen" 3 "usual" 4 "very usual"
label values vill_burn villburn

* perception of violence index

replace ten_tension = . if ten_tension > 10 & !missing(ten_tension)

foreach var in ten_tension vill_burn {
sum `var' if treatment == 0
gen `var'_std = (`var' - r(mean))/r(sd)
}

egen vperception = rowtotal(ten_tension_std vill_burn_std), missing
replace vperception = vperception/2
replace vperception = -vperception // higher values are better
label variable vperception "\makecell{Violence \\ perceptions}"
drop ten_tension_std vill_burn_std

label variable for_trust_1 "Out of 10 people, how many are honest?"
label variable enemy "Are there people who hate you?"

label variable institution1 "If your family is sick, can you access hospital?"
label variable institution2 "If there is conflict, can you trust that police will intervene?"

local comps mentalhealth futureexp socstanding socialcohesion collective vperception 

egen psychosocial = rowtotal(`comps'), missing
sum psychosocial if treatment == 0
replace psychosocial = psychosocial - r(mean)
replace psychosocial = psychosocial/r(sd)
sum psychosocial
label variable psychosocial "Psychosocial well-being index"


* module 13 future expectations

label variable att_meteo "Favourable weather last season?"
label variable att_meteo_esp "Expect favourable weather this season?"
label variable att_last_crop "How was last harvest?"
label variable att_next_crop "Expectation for next harvest?"
label variable att_other_bus "Member of other household activities?"
label variable att_last_rev "Assess non-agri income spend?"
label variable att_next_rev "Expectation for non-agri income?"
label variable att_govhelp "Expect to receive gov aid this year?"
label variable att_govhelp_amt "How much gov aid?"

* module 14 risk preferences

label variable pref_renonce "Willing to give up money today?"

/*
9.2: Suppose someone you fully trust offers you 19,000 CFA as a gift today. 
But he tells you that if you wait 1 month, you will receive 20,000 CFA in 1 month (certainly) instead of 19,000 CFA today:
*/

label variable pref_1_19000f "19.000 CFA today or 20.000 CFA in one month?"
label variable pref_1_18000f "18.000 CFA today or 20.000 CFA in one month?"
label variable pref_1_16000f "16.000 CFA today or 20.000 CFA in one month?"
label variable pref_1_14000f "14.000 CFA today or 20.000 CFA in one month?"
label variable pref_1_11000f "11.000 CFA today or 20.000 CFA in one month?"
label variable pref_1_8000f "8.000 CFA today or 20.000 CFA in one month?"
label variable pref_1_5000f "5.000 CFA today or 20.000 CFA in one month?"
label variable pref_1_500f "500 CFA today or 20.000 CFA in one month?"


/*
9.3: Suppose someone you fully trust will offer you 19,000 CFA as a gift 
in 1 month (certainly). But he tells you that if you wait 2 months, you will 
receive 20,000 CFA in 2 months (certainly) instead of 19,000 CFA in 1 month.
*/

label variable pref_2_19000f "19.000 CFA in one month or 20.000 CFA in two months?"
label variable pref_2_18000f "18.000 CFA in one month or 20.000 CFA in two months?"
label variable pref_2_16000f "16.000 CFA in one month or 20.000 CFA in two months?"
label variable pref_2_14000f "14.000 CFA in one month or 20.000 CFA in two months?"
label variable pref_2_11000f "11.000 CFA in one month or 20.000 CFA in two months?"
label variable pref_2_8000f "8.000 CFA in one month or 20.000 CFA in two months?"
label variable pref_2_5000f "5.000 CFA in one month or 20.000 CFA in two months?"
label variable pref_2_500f "500 CFA in one month or 20.000 CFA in two months?"


label variable pref_prog "Distribute 120.000 CFA?"
label variable pref_prog_why "Why this distribution?"

label define pref_prog ///
1 "20,000 every two months for a year" ///
2 "All at once" ///
3 "Half now, and half after six months", replace

label values pref_prog pref_prog

label variable risk_take "\makecell{Willing to \\ take risks?}"
label variable risk_conf_poeple "\makecell{People can \\ be trusted?}"
label variable risk_conf_gov "\makecell{Trust gov to \\ care for people?}"

label define risk_take 1 "Least willing" 10 "Most willing", replace
label values risk_take risk_take

recode risk_conf_poeple (1= 3) (2 = 2) (3 = 1)
label define risk_conf_poeple 3 "Most people can be trusted" 2 "Neutral" 1 "You have to be very careful", replace
label values risk_conf_poeple risk_conf_poeple

label define risk_conf_gov 1 "Low confidence" 10 "High confidence", replace
label values risk_conf_gov risk_conf_gov

// twoway (histogram risk_conf_gov, discrete percent), xlab(1/10, valuelabel)
//
// graph export "$endline/output/final/risk-conf-gov.pdf", replace
//
// twoway (histogram risk_conf_poeple, discrete percent), xlab(1/3, valuelabel)
//
// graph export "$endline/output/final/risk-conf-people.pdf", replace
//
// twoway (histogram risk_take, discrete percent), xlab(1/10, valuelabel)
//
// graph export "$endline/output/final/risk-take.pdf", replace

* module 15 other programs wide and long format

label variable prog_1 "Cereals"
label variable prog_2 "Public works"
label variable prog_3 "Donation of food for children"
label variable prog_4 "Social protection"
label variable prog_4 "Social protection: cash or asset transfer"
label variable prog_5 "Cash or asset transfer via NGO"
label variable prog_6 "Business program"
label variable prog_7 "Insurance"
label variable prog_8 "Health programs"
label variable prog_9 "Health insurance"
label variable prog_10 "Savings program"
label variable prog_11 "Nutrition program"
label variable prog_12 "Other program"

drop resp_prog_*

save "${endline_final}/main_build_temp.dta", replace

clear
use "${endline_intermediate}/programs-rpt_prog.dta"

sort hhid prog_pos, stable
label variable prog_name "Name of program"
label variable prog_mem "Which members received transfer?"

drop prog_mem_*
capture drop parent_key key

gen multiples = wordcount(prog_mem)
order multiples, after(prog_mem)

replace prog_xof = . if prog_xof < 0

sum prog_xof

foreach var in prog_xof {
    _pctile `var', p(2, 98)
    ret list
    replace `var' = r(r1) if `var' < r(r1)
    replace `var' = r(r2) if `var' > r(r2) & !missing(`var')
}

sum prog_xof

by hhid: egen count_transfers = total(multiples)
by hhid: egen amt_transfer = total(prog_xof)

keep hhid count_transfers amt_transfer
duplicates drop

label variable count_transfers "\# of transfers received"
label variable amt_transfer "Amount received"

tempfile transfers
save "`transfers'"

clear

use "${endline_final}/main_build_temp.dta"

merge 1:1 hhid using "`transfers'"
drop _merge


* module 16 social protection programs

label variable ctrans_d "Received social protection transfer?"
label variable ctrans_others "Other HH received social protection transfer?"
label variable ctrans_whoelse "Which other HH received SP transfer?"
label variable ctrans_when_start "When did SP start?"
label variable ctrans_when_last "When was last SP transfer?"
label variable ctrans_amt "What was last SP amount?"
label variable ctrans_reason "Reason for this SP?"
label variable ctrans_paid "Paid someone to receive SP?"
label variable ctrans_paid_amt "How much did you pay?"

gen count_sp = wordcount(resp_ctrans)
label variable count_sp "\# of HH who received SP"

drop resp_ctrans
drop resp_ctrans_*
drop ctrans_whoelse_*

* module 17 transfers (past six months) wide and long format

label variable trans_fam "\makecell{Received \\ remittances?}"
label variable trans_fam_send "\makecell{Sent \\ remittances?}"
label variable trans_n "How many remittances received?"
label variable trans_n_send "How many remittances sent?"

drop rpt_trans_count rpt_trans_send_count
drop resp_trans_*

save "${endline_final}/main_build_temp.dta", replace

clear
use "${endline_intermediate}/transfers-rpt_trans.dta"

sort hhid trans_pos, stable
order hhid trans_pos trans_freq

by hhid: egen remittance_amt = total(trans_amt), missing

foreach var in remittance_amt {
    _pctile `var', p(98)
    ret list
    replace `var' = r(r1) if `var' > r(r1) & !missing(`var')
    replace `var' = 0 if missing(`var')
}

by hhid: egen xx = min(trans_freq)
sum xx
order xx, after(trans_freq)
keep hhid xx remittance_amt
label variable remittance_amt "\makecell{Remittance \\ amount}"

duplicates drop

* dividing so that it is comparable to previous rounds
replace remittance_amt = remittance_amt / 6

rename xx reg_transfer
tab reg_transfer, m
replace reg_transfer = 1 if reg_transfer < 5
replace reg_transfer = 0 if reg_transfer > 4

label define reg_transfer 0 "No" 1 "Yes"
label values reg_transfer reg_transfer
label variable reg_transfer "Regular transfers"

tempfile reg_transfer
save "`reg_transfer'"
clear

use "${endline_final}/main_build_temp.dta"
merge 1:1 hhid using "`reg_transfer'"
drop _merge

save "${endline_final}/main_build_temp.dta", replace

clear
use "${endline_intermediate}/transfers-rpt_trans_send.dta"

sort hhid trans_pos_send, stable
order hhid trans_pos_send trans_freq_send

by hhid: egen remittance_sent_amt = total(trans_amt_send), missing

foreach var in remittance_sent_amt {
    _pctile `var', p(98)
    ret list
    replace `var' = r(r1) if `var' > r(r1) & !missing(`var')
    replace `var' = 0 if missing(`var')
}

by hhid: egen xx = min(trans_freq_send)
sum xx
order xx, after(trans_freq_send)
keep hhid xx remittance_sent_amt
label variable remittance_sent_amt "\makecell{Remittance \\ amount}"
duplicates drop

* dividing so that it is comparable to previous rounds
replace remittance_sent_amt = remittance_sent_amt / 6

rename xx reg_transfer_send
tab reg_transfer_send, m
replace reg_transfer_send = 1 if reg_transfer_send < 5
replace reg_transfer_send = 0 if reg_transfer_send > 4

label define reg_transfer_send 0 "No" 1 "Yes"
label values reg_transfer_send reg_transfer_send
label variable reg_transfer_send "Send regular transfers"

tempfile reg_transfer_send
save "`reg_transfer_send'"
clear

use "${endline_final}/main_build_temp.dta"
merge 1:1 hhid using "`reg_transfer_send'"
drop _merge

save "${endline_final}/main_build_temp.dta", replace

* module 18 shocks

drop shock_has

label variable shock1 "Drought"
label variable shock2 "Flood"
label variable shock3 "Crop disease"
label variable shock4 "Animal disease"
label variable shock5 "Increase in agri input prices"
label variable shock6 "Decrease in agri output prices"
label variable shock7 "Increase in food prices"
label variable shock8 "Loss of non-agri income"
label variable shock9 "Serious illness in HH"
label variable shock10 "Death of HH member"
label variable shock11 "Divorce"
label variable shock12 "Theft of money, goods"
label variable shock13 "Other shock"

label variable shock_n "Number of shocks"

drop calc_shock*

label variable shock_affect "Shock during the rainy season?"

drop resp_shock
drop resp_shock_*

* module 19 adaptation to shocks / coping strategies

* past 12 months

label variable choc_strategy1 "Sale of cattle"
label variable choc_strategy2 "Stock of food products"
label variable choc_strategy3 "Use of savings"

label variable choc_strategy4 "Reduce food expenditure or change of food habits"
label variable choc_strategy5 "Sale of productive assets"
label variable choc_strategy6 "Reduction of health/education expenditure"
label variable choc_strategy7 "Reduction of non-food expenses"

label variable choc_strategy8  "Sale of durable household goods"
label variable choc_strategy9 "Credit"
label variable choc_strategy10 "Household members have taken additional activities"
label variable choc_strategy11 "Migrate"
label variable choc_strategy12 "Help from relatives or friends"
label variable choc_strategy13 "Aid of the Government/State"
label variable choc_strategy14 "NGO help"
label variable choc_strategy15 "Help of religious organizations"
label variable choc_strategy16 "God"
label variable choc_strategy17 "No strategy"
label variable choc_strategy19 "Adapation of agricultural behavior"
label variable choc_strategy18 "Another strategy (specify)"

* during july - september 2022; asked if above response is yes to atleast one

label variable choc_strategy1u "Sale of cattle"
label variable choc_strategy2u "Stock of food products"
label variable choc_strategy3u "Use of savings"

label variable choc_strategy4u "Reduce food expenditure or change of food habits"
label variable choc_strategy5u "Sale of productive assets"
label variable choc_strategy6u "Reduction of health/education expenditure"
label variable choc_strategy7u "Reduction of non-food expenses"

label variable choc_strategy8u  "Sale of durable household goods"
label variable choc_strategy9u "Credit"
label variable choc_strategy10u "Household members have taken additional activities"
label variable choc_strategy11u "Migrate"
label variable choc_strategy12u "Help from relatives or friends"
label variable choc_strategy13u "Aid of the Government/State"
label variable choc_strategy14u "NGO help"
label variable choc_strategy15u "Help of religious organizations"
label variable choc_strategy16u "God"

label variable choc_strategy19u "Adapation of agricultural behavior"
label variable choc_strategy18u "Another strategy (specify)"

drop resp_strategy_*

save "${endline_final}/final.dta", replace
